(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    246333,       5304]*)
(*NotebookOutlinePosition[    247112,       5331]*)
(*  CellTagsIndexPosition[    247068,       5327]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["\<\
This document is based on the notebook for International \
Mathematica Symposium 2005.\
\>", "Text"],

Cell[CellGroupData[{

Cell["SNAP`", "Section"],

Cell[TextData[StyleBox["Kosaku Nagasaka",
  FontWeight->"Bold",
  FontSlant->"Plain"]], "Text",
  TextAlignment->Right,
  TextJustification->0],

Cell["\<\
SNAP (Symbolic Numeric Algebra for Polynomials) is a prototype \
package that includes basic functions for computing approximate algebraic \
properties, such as the approximate gcd of polynomials. \
\>", "Abstract",
  CellMargins->{{25, 26}, {Inherited, Inherited}},
  TextAlignment->Left,
  TextJustification->0]
}, Open  ]],

Cell[CellGroupData[{

Cell["Introduction", "Chapter"],

Cell[TextData[{
  "Recently, there are a lot of results in the area called Symbolic Numeric \
Algebra, especially for polynomials (for example, approximate GCD for \
univariate polynomials [Pan98, Pan01, BL98, EGL97] and approximate \
factorization for bivariate polynomials [CGHKW01, MU88, Sas01, WSZ00]). We \
think that those results have been getting practical qualities, and we should \
combine them and implement it into integrated one computer algebra system \
such as ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". In fact, ",
  StyleBox["Maple",
    FontSlant->"Italic"],
  " has such a special package called \[OpenCurlyDoubleQuote]SNAP\
\[CloseCurlyDoubleQuote] (Symbolic-Numeric Algorithms for Polynomials). \
Unfortunately, there is no such a package for ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", currently, except for this package."
}], "Text"],

Cell[TextData[{
  "We have been developing our \[OpenCurlyDoubleQuote]SNAP",
  "\[CloseCurlyDoubleQuote]",
  " package for ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", and it is an abbreviation for Symbolic Numeric ",
  StyleBox["Algebra",
    FontWeight->"Bold"],
  " for Polynomials. By Algebra, we mean that continuous capabilities of \
approximate operations: for example, computing an approximate GCD between an \
empirical polynomial and a polynomial which is the nearest singular \
polynomial computed by SNAP functions, of another empirical polynomial. This \
continuous applicability is more important for practical computations. \
Especially for average users, it is more important than the number of \
algorithms that are already implemented."
}], "Text"],

Cell[TextData[{
  "Our aim of this package is providing practical implementations of SNAP \
functions with an unified tolerance mechanism for polynomials like ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s floating-point numbers or Kako and Sasaki's effective floating-point \
number [KS97]. Our idea is very simple. We only have to add 1) new data \
structures representing such polynomials with tolerances, 2) basic \
calculation routines for the structures and 3) SNAP functions for the \
structures. We note that the package does not have enough functionality yet \
for now, comparing with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s floating-point numbers, since the package is an on-going project (we \
have a plan on which the version 1.0 will be released on Mar. 2007). At this \
time, simple tolerance representations, ",
  Cell[BoxData[
      \(TraditionalForm\`l\^2\)]],
  "-norm, ",
  Cell[BoxData[
      \(TraditionalForm\`l\^1\)]],
  "-norm and ",
  Cell[BoxData[
      \(TraditionalForm\`l\^\[Infinity]\)]],
  "-norm for coefficients vectors of polynomials, and a few SNAP functions \
are only implemented."
}], "Text"],

Cell["\<\
We note that this research is partly helped by Grants-in-Aid for \
Scientific Research, Ministry of Education, Culture, Sports, Science and \
Technology, JAPAN, #16700016.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Tolerance Mechanisms and Implementations", "Chapter"],

Cell[TextData[{
  "First of all, we introduce a framework of our package, which includes SNAP \
structures and its implementations by using ",
  ButtonBox["UpSetDelayed",
    ButtonStyle->"RefGuideLink"],
  ", ",
  ButtonBox["Format",
    ButtonStyle->"RefGuideLink"],
  " and others."
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {Cell["function"], Cell["purpose"]},
          {
            StyleBox["SNAP",
              
              FontFamily->
                "Courier"], \(converts\ the\ given\ polynomial\ to\ its\ SNAP\
\ \(\(representation\)\(.\)\)\)},
          {
            StyleBox["Normal",
              
              FontFamily->
                "Courier"], \(converts\ the\ given\ SNAP\ representation\ to\ \
its\ normal\ polynomial\ \(\(expression\)\(.\)\)\)},
          {
            StyleBox["SNAPQ",
              FontFamily->"Courier"], 
            RowBox[{
            "tests", " ", "whether", " ", "the", " ", "given", " ", 
              "expression", " ", "is", " ", 
              StyleBox["a",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], " ", "SNAP", " ", "structure", " ", 
              "or", " ", \(\(not\)\(.\)\)}]},
          {
            StyleBox["Tolerance",
              
              FontFamily->
                "Courier"], \(gives\ the\ tolerance\ of\ the\ given\ SNAP\ \(\
\(structure\)\(.\)\)\)},
          {
            StyleBox["SetTolerance",
              
              FontFamily->
                "Courier"], \(overwrite\ the\ tolerance\ of\ the\ given\ SNAP\
\ \(\(structure\)\(.\)\)\)},
          {
            StyleBox["TransformSNAP",
              
              FontFamily->
                "Courier"], \(converts\ the\ given\ SNAP\ structure\ with\ \
another\ scheme\ to\ that\ with\ the\ given\ \(\(scheme\)\(.\)\)\)},
          {
            "Element", \(tests\ whether\ the\ given\ polynomial\ is\ in\ the\ \
given\ SNAP\ structure\ or\ \(\(not\)\(.\)\)\)},
          {
            "Expand", \(the\ same\ effect\ as\ the\ builtin\ \
\(\(function\)\(.\)\)\)},
          {
            "ReplaceAll", \(the\ same\ effect\ as\ the\ builtin\ \(\(function\
\)\(.\)\)\)}
          }], TraditionalForm]], "DisplayFormula",
  GridBoxOptions->{RowLines->{2, 0.5},
  ColumnLines->True},
  CellTags->"Groups:classical groups"]], "DefinitionBox"],

Cell[TextData[{
  StyleBox["Table ", "SB"],
  StyleBox[
  CounterBox["NumberedTable"], "SB"],
  StyleBox[". ", "SB"],
  "Basic Functions"
}], "SmallTextSans",
  CellMargins->{{27, Inherited}, {Inherited, Inherited}}],

Cell[CellGroupData[{

Cell["Tolerance Examples", "Section"],

Cell["\<\
We show some examples of the package, about its tolerance \
mechanism. At first, this loads the package.\
\>", "Text"],

Cell[BoxData[
    \(Needs["\<SNAP`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell[TextData[Cell[BoxData[GridBox[{
        {Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .40092 
%%ImageSize: 218 88 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
4.33681e-19 0.00460829 -0.00460829 0.00460829 [
[ 0 0 0 0 ]
[ 1 .40092 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .40092 L
0 .40092 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
0 -0.00461 translate
1.00461 .40553 scale
654 string
218 88 8 [218 0 0 88 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF4040FF7F7FFF7F7FFF7F7FFF7F7FFF7F7FFF7F7FFF7F7FFF7F7FFF7F7FFF
7F7FFF7F7FFF7F7FFF7F7FFF7F7FFF7F7FFF2020FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF1010FF4040FF4040FF4040FF4040FF4040FF1010FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2020FF
7070FF9999FFCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFFF
BFBFFF8F8FFF5050FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FF7F7FFFAFAFFFBFBFFF
EFEFFFFFFFFFFFFFFFFFFFFFCCCCFFBFBFFF8F8FFF6666FF2020FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6666FFDFDFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF9999FF3333FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFFF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF4040FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
BFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8080FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFFF8F8FFF2020FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8080FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFFF3333FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFFF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF4040FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
BFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8080FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
BFBFFF4040FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8080FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFFF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF4040FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
BFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8080FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFBFBFFF2020FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8080FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFF1010FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFFF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF4040FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
BFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8080FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF7070FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8080FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFFF3333FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFFF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF4040FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
BFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8080FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFF1010FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8080FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFF
1010FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFFF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF4040FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
BFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8080FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFF1010FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8080FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AFAFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFFF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF4040FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
BFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8080FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFF1010FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8080FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF6666FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFFF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF4040FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
BFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8080FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFF1010FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8080FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFEFEFFF1010FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFFF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF4040FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
BFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8080FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9999FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8080FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF8080FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFFF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF4040FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
BFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8080FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6666FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8080FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFDFDFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFFF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF4040FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
BFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8080FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFFF1010FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8080FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF3333FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFFF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF4040FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
BFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8080FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9999FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8080FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF8080FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFFF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF4040FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
BFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8080FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
2020FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8080FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFBFBFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFFF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF4040FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
BFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8080FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
9999FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8080FFFFFFFFFFFFFF
FFFFFFEFEFFFBFBFFFBFBFFFBFBFFFCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFDFDFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFFF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF4040FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
BFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8080FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FFFFFFFFFFFFFFEFEFFF
BFBFFFBFBFFFBFBFFFBFBFFFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
EFEFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8080FFDFDFFF7070FF
2020FF0000FF0000FF0000FF0000FF0000FF1010FF7070FFEFEFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFFF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF4040FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
BFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8080FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FF8F8FFF3333FF0000FF
0000FF0000FF0000FF0000FF0000FF3333FF9999FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF5050FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1010FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1010FFCCCCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFFF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF4040FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
BFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8080FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF3333FFDFDFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF8F8FFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1010FFEFEFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFFF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF4040FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7FFF7F7FFF7F7FFF
7F7FFF7F7FFF7F7FFF7F7FFF7F7FFF7F7FFF7F7FFF7F7FFF7F7FFF7F7FFF7F7FFF7F7FFF
DFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8080FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2020FFEFEFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFCCCCFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8F8FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFFF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF4040FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8080FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF4040FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8080FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFFF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF4040FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8080FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFCCCCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF4040FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8080FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFEFEFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFFF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF4040FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8080FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF7070FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF4040FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFCCCCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFBFBFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFFF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF4040FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8080FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF4040FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF6666FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2020FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF8F8FFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFFF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF4040FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8080FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF3333FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF8080FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFAFAFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF5050FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFFF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF4040FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8080FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2020FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF8080FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF4040FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFFF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF4040FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8080FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF7070FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7070FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF4040FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF8080FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF2020FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF6666FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
8080FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF4040FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFBFBFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFBFBFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF6666FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8FFF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7070FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
9999FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFBFBFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFBFBFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF2020FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5050FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFFF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF4040FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
BFBFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFAFAFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFBFBFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF9999FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFFF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF2020FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
BFBFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF4040FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF6666FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFBFBFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF2020FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF1010FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3333FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF2020FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8080FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
7070FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
DFDFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFDFDFFF1010FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF9999FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFBFBFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF5050FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF3333FFDFDFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6666FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF6666FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFCCCCFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1010FF
EFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF2020FFCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF3333FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFBFBFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF9999FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1010FF9999FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFFF3333FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF9999FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF3333FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFAFAFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF4040FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF1010FF7070FFAFAFFFBFBFFFBFBFFF7070FF
1010FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFBFBFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFEFEFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1010FF
6666FF8080FF9999FF8080FF8080FF3333FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF8F8FFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF4040FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF8080FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF4040FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFBFBFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
4040FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF5050FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
6666FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF1010FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1010FFDFDFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFCCCCFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFBFBFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
4040FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFBFBFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
BFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF8080FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF8F8FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF2020FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF1010FFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFBFBFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
4040FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3333FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF4040FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF1010FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF3333FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF9999FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF6666FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFBFBFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
4040FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFFF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFCCCCFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF9999FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFBFBFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF2020FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFBFBFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
4040FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7070FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF7070FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF2020FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF6666FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF9999FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFBFBFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
4040FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFFF3333FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF3333FFEFEFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
CCCCFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF1010FFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF3333FFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFBFBFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
4040FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFF1010FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1010FFCCCCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
8F8FFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF7070FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFEFEFFF1010FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF1010FFCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFBFBFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
4040FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFFF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFAFAFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
4040FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFF1010FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF9999FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFBFBFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
4040FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9999FF1010FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF9999FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF3333FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFF1010FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
9999FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFEFEFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFEFEFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
1010FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFF1010FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF1010FFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFFF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFF3333FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1010FFBFBFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFBFBFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFFF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFFF
4040FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF3333FFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFFF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFFF6666FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF4040FFDFDFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF1010FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF7070FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFFF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF8F8FFF1010FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF1010FF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFFF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF8080FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFFF3333FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF2020FF9999FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF4040FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF1010FFEFEFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4040FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFEFEFFF6666FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF6666FFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFFF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF4040FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
BFBFFF5050FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF3333FF9999FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF7070FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF5050FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9999FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF3333FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFDFDFFF7F7FFF2020FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF2020FF7F7FFF
DFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFFF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFEFEFFF9999FF6666FF3333FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF2020FF5050FF8F8FFFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF9999FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6666FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9999FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF6666FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFF8F8FFF4040FF2020FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF2020FF5050FF7F7FFFCCCCFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFFF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF1010FFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFFBFBFFFBFBFFFDFDFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFDFDFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
2020FFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFFF6666FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF9999FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFBFBFFFBFBFFFBFBFFFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6666FFAFAFFFFFFFFFFFFFFF
FFFFFFFFFFFFBFBFFF7070FFCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF2020FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF1010FF4040FF4040FF4040FF2020FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
2020FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7070FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF4040FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
6666FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFFF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF9999FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AFAFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5050FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF2020FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF1010FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFFF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF9999FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF8080FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6666FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF3333FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFDFDFFF1010FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFFF1010FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF8080FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFFF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF3333FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9999FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6666FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFCCCCFF1010FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7070FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF3333FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFBFBFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6666FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF3333FFEFEFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9999FF1010FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
9999FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF6666FFEFEFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFF2020FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFBFBFFF2020FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF7F7FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFFF6666FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFEFEFFF6666FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF3333FFCCCCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFFF4040FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFCCCCFF4040FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF2020FF9999FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFFF
5050FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCCCCFF6666FF1010FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF5050FFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFEFEFFFAFAFFF6666FF4040FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF1010FF4040FF7F7FFFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFFF7F7FFF4040FF
1010FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF4040FF7070FFAFAFFF
EFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFFFBFBFFFBFBFFFBFBFFFBFBFFFBFBFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCCCCFFBFBFFFBFBFFFBFBFFFBFBFFFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
            ImageSize->{218, 88},
            ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003J0000F2000`400?l00000o`00003ofP000?l0
0=X0003o003J0000o`00fP000?l009h0003o00<0@43o07moo`1oOol03@1oOol00`0P8?l0003o0000
o`0Y0000o`00WP000?l00`20P?l0oooo0?ooo`0=0?ooo`030410o`000?l0003o02T0003o002N0000
o`030820o`3oool0oooo00d0oooo00<0@43o0000o`000?l0:@000?l009h0003o00<0P83o0?ooo`3o
ool03@3oool00`10@?l0003o0000o`0Y0000o`00WP000?l00`20P?l0oooo0?ooo`0=0?ooo`030410
o`000?l0003o02T0003o002N0000o`030820o`3oool0oooo00d0oooo00<0@43o0000o`000?l0:@00
0?l009h0003o00<0P83o0?ooo`3oool03@3oool00`10@?l0003o0000o`0Y0000o`00WP000?l00`20
P?l0oooo0?ooo`0=0?ooo`030410o`000?l0003o02T0003o002N0000o`030820o`3oool0oooo00d0
oooo00<0@43o0000o`000?l0:@000?l009h0003o00<0P83o0?ooo`3oool03@3oool00`10@?l0003o
0000o`0Y0000o`00WP000?l00`20P?l0oooo0?ooo`0=0?ooo`030410o`000?l0003o02T0003o002N
0000o`030820o`3oool0oooo00d0oooo00<0@43o0000o`000?l0:@000?l009h0003o00<0P83o0?oo
o`3oool03@3oool00`10@?l0003o0000o`0Y0000o`00WP000?l00`20P?l0oooo0?ooo`0=0?ooo`03
0410o`000?l0003o02T0003o002N0000o`030820o`3oool0oooo00d0oooo00<0@43o0000o`000?l0
:@000?l009h0003o00<0P83o0?ooo`3oool03@3oool00`10@?l0003o0000o`0Y0000o`0040000?l0
0`0@4?l0@43o0410o`030410o`03010@o`000?l0003o08D0003o00<0P83o0?ooo`3oool03@3oool0
0`10@?l0003o0000o`0Y0000o`002`000?l0100P8?l0L73o09VIo`3<c?l80?ooo`040>o_o`2o_ol0
Shoo051@oh<0003o00<0P83o0?ooo`3oool03@3oool01`10@?l0003o0000o`1oOol0[joo0;noo`3_
kol00`3oool01@3<c?l0_koo08n?o`1VI_l0823o01d0003o00090000o`0306IVo`3Ogol0oooo0100
oooo00<0VIWo03<co`000?l04@000?l00`20P?l0oooo0?ooo`0=0?ooo`030410o`000?l0003o00P0
003o3`3oool00`2o_ol0003o0000o`060000o`030410o`3oool0oooo00l0oooo3`000?l00`2o_ol0
oooo0?ooo`0>0?ooo`030820o`000?l0003o00H0003o00<0P83o0?ooo`3oool03@3oool00`10@?l0
003o0000o`0<0?ooo`030=oOo`2?Sol0823o01X0003o00090000o`030820o`3oool0oooo0180oooo
00<0_koo03<co`000?l03`000?l00`20P?l0oooo0?ooo`0=0?ooo`030410o`000?l0003o00P0003o
3`3oool00`2o_ol0003o0000o`060000o`030410o`3oool0oooo00l0oooo3`000?l00`2o_ol0oooo
0?ooo`0>0?ooo`030820o`000?l0003o00H0003o00<0P83o0?ooo`3oool03@3oool00`10@?l0003o
0000o`0?0?ooo`030;noo`10@?l0003o01L0003o00090000o`030820o`3oool0oooo01@0oooo00<0
Shoo0000o`000?l03@000?l00`20P?l0oooo0?ooo`0=0?ooo`030410o`000?l0003o00P0003o3`3o
ool00`2o_ol0003o0000o`060000o`030410o`3oool0oooo00l0oooo3`000?l00`2o_ol0oooo0?oo
o`0>0?ooo`030820o`000?l0003o00H0003o00<0P83o0?ooo`3oool03@3oool00`10@?l0003o0000
o`0A0?ooo`030;noo`0P8?l0003o01D0003o00090000o`030820o`3oool0oooo01D0oooo00<0c<co
010@o`000?l030000?l00`20P?l0oooo0?ooo`0=0?ooo`030410o`000?l0003o00P0003o3`3oool0
0`2o_ol0003o0000o`060000o`030410o`3oool0oooo00l0oooo3`000?l00`2o_ol0oooo0?ooo`0>
0?ooo`030820o`000?l0003o00H0003o00<0P83o0?ooo`3oool03@3oool00`10@?l0003o0000o`0C
0?ooo`03071`o`000?l0003o01<0003o00090000o`030820o`3oool0oooo01H0oooo00<0knoo03<c
o`000?l02`000?l00`20P?l0oooo0?ooo`0=0?ooo`030410o`000?l0003o00P0003o3`3oool00`2o
_ol0003o0000o`060000o`030410o`3oool0oooo00l0oooo3`000?l00`2o_ol0oooo0?ooo`0>0?oo
o`030820o`000?l0003o00H0003o00<0P83o0?ooo`3oool03@3oool00`10@?l0003o0000o`0D0?oo
o`030:n_o`0@4?l0003o0180003o00090000o`030820o`3oool0oooo01L0oooo00<0c<co010@o`00
0?l02P000?l00`20P?l0oooo0?ooo`0=0?ooo`030410o`000?l0003o00P0003o3`3oool00`2o_ol0
003o0000o`060000o`030410o`3oool0oooo00l0oooo3`000?l00`2o_ol0oooo0?ooo`0>0?ooo`03
0820o`000?l0003o00H0003o00<0P83o0?ooo`3oool03@3oool00`10@?l0003o0000o`0E0?ooo`03
0<c<o`0@4?l0003o0140003o00090000o`030820o`3oool0oooo01P0oooo00<0[joo0000o`000?l0
2@000?l00`20P?l0oooo0?ooo`0=0?ooo`030410o`000?l0003o00P0003o3`3oool00`2o_ol0003o
0000o`060000o`030410o`3oool0oooo00l0oooo3`000?l00`2o_ol0oooo0?ooo`0>0?ooo`030820
o`000?l0003o00H0003o00<0P83o0?ooo`3oool03@3oool00`10@?l0003o0000o`0F0?ooo`030<c<
o`0@4?l0003o0100003o00090000o`030820o`3oool0oooo01T0oooo00<0IVKo0000o`000?l02000
0?l00`20P?l0oooo0?ooo`0=0?ooo`030410o`000?l0003o00P0003o3`3oool00`2o_ol0003o0000
o`060000o`030410o`3oool0oooo00l0oooo3`000?l00`2o_ol0oooo0?ooo`0>0?ooo`030820o`00
0?l0003o00H0003o00<0P83o0?ooo`3oool03@3oool00`10@?l0003o0000o`0G0?ooo`030<c<o`0@
4?l0003o00l0003o00090000o`030820o`3oool0oooo01T0oooo00<0knoo010@o`000?l020000?l0
0`20P?l0oooo0?ooo`0=0?ooo`030410o`000?l0003o00P0003o3`3oool00`2o_ol0003o0000o`06
0000o`030410o`3oool0oooo00l0oooo3`000?l00`2o_ol0oooo0?ooo`0>0?ooo`030820o`000?l0
003o00H0003o00<0P83o0?ooo`3oool03@3oool00`10@?l0003o0000o`0H0?ooo`0309VIo`000?l0
003o00h0003o00090000o`030820o`3oool0oooo01X0oooo00<0P83o0000o`000?l01`000?l00`20
P?l0oooo0?ooo`0=0?ooo`030410o`000?l0003o00P0003o3`3oool00`2o_ol0003o0000o`060000
o`030410o`3oool0oooo00l0oooo3`000?l00`2o_ol0oooo0?ooo`0>0?ooo`030820o`000?l0003o
00H0003o00<0P83o0?ooo`3oool03@3oool00`10@?l0003o0000o`0I0?ooo`0306IVo`000?l0003o
00d0003o00090000o`030820o`3oool0oooo01X0oooo00<0gmoo0000o`000?l01`000?l00`20P?l0
oooo0?ooo`0=0?ooo`030410o`000?l0003o00P0003o3`3oool00`2o_ol0003o0000o`060000o`03
0410o`3oool0oooo00l0oooo3`000?l00`2o_ol0oooo0?ooo`0>0?ooo`030820o`000?l0003o00H0
003o00<0P83o0?ooo`3oool03@3oool00`10@?l0003o0000o`0I0?ooo`030>o_o`0@4?l0003o00d0
003o00090000o`030820o`3oool0oooo01/0oooo00<0<c?o0000o`000?l01P000?l00`20P?l0oooo
0?ooo`0=0?ooo`030410o`000?l0003o00P0003o3`3oool00`2o_ol0003o0000o`060000o`030410
o`3oool0oooo00l0oooo3`000?l00`2o_ol0oooo0?ooo`0>0?ooo`030820o`000?l0003o00H0003o
00<0P83o0?ooo`3oool03@3oool00`10@?l0003o0000o`0J0?ooo`0309VIo`000?l0003o00`0003o
00090000o`030820o`3oool0oooo01/0oooo00<0P83o0000o`000?l01P000?l00`20P?l0oooo0?oo
o`0=0?ooo`030410o`000?l0003o00P0003o3`3oool00`2o_ol0003o0000o`060000o`030410o`3o
ool0oooo00l0oooo3`000?l00`2o_ol0oooo0?ooo`0>0?ooo`030820o`000?l0003o00H0003o00<0
P83o0?ooo`3oool03@3oool00`10@?l0003o0000o`0K0?ooo`03020Po`000?l0003o00/0003o0009
0000o`030820o`3oool0oooo01/0oooo00<0_koo0000o`000?l01P000?l00`20P?l0oooo0?ooo`0=
0?ooo`030410o`000?l0003o00P0003o3`3oool00`2o_ol0003o0000o`060000o`030410o`3oool0
oooo00l0oooo3`000?l00`2o_ol0oooo0?ooo`0>0?ooo`030820o`000?l0003o00H0003o00<0P83o
0?ooo`3oool03@3oool00`10@?l0003o0000o`0K0?ooo`0309VIo`000?l0003o00/0003o00090000
o`050820o`3oool0oooo0?ooo`3_kol00`2o_ol00`3<c?l0oooo0?ooo`0C0?ooo`030=oOo`000?l0
003o00H0003o00<0P83o0?ooo`3oool03@3oool00`10@?l0003o0000o`080000o`l0oooo00<0_koo
0000o`000?l01P000?l00`10@?l0oooo0?ooo`0?0?ooo`l0003o00<0_koo0?ooo`3oool03P3oool0
0`20P?l0003o0000o`060000o`030820o`3oool0oooo00d0oooo00<0@43o0000o`000?l00P3oool0
0`3_kol0_koo0;noo`020;noo`030>o_o`3oool0oooo0140oooo00<0knoo0000o`000?l02`000?l0
00T0003o00@0P83o0=oOo`1`L?l0823o1@000?l00`0@4?l0L73o0>o_o`0C0?ooo`P0003o00<0P83o
0?ooo`3oool03@3oool00`10@?l0003o0000o`080000o`l0oooo00<0_koo0000o`000?l01P000?l0
0`10@?l0oooo0?ooo`0?0?ooo`l0003o00<0_koo0?ooo`3oool03P3oool00`20P?l0003o0000o`06
0000o`030820o`3oool0oooo00d0oooo00D0@43o0000o`000?l0Shoo03<co`060000o`0303<co`2I
VOl0oooo0140oooo00<0D53o0000o`000?l02P000?l000T0003o00<0413o0000o`000?l020000?l0
0`0@4?l0c<co0?ooo`0A0?ooo`P0003o00<0P83o0?ooo`3oool03@3oool00`10@?l0003o0000o`08
0000o`l0oooo00<0_koo0000o`000?l01P000?l00`10@?l0oooo0?ooo`0?0?ooo`l0003o00<0_koo
0?ooo`3oool03P3oool00`20P?l0003o0000o`060000o`030820o`3oool0oooo00d0oooo00<0@43o
0000o`000?l02P000?l00`0c<ol0gmoo0?ooo`0?0?ooo`0308n?o`000?l0003o00X0003o000E0000
o`03010@o`3_kol0oooo0100oooo20000?l00`20P?l0oooo0?ooo`0=0?ooo`030410o`000?l0003o
00P0003o3`3oool00`2o_ol0003o0000o`060000o`030410o`3oool0oooo00l0oooo3`1oOol00`3O
gol0oooo0?ooo`0>0?ooo`030820o`000?l0003o00H0003o00<0P83o0?ooo`3oool03@3oool00`10
@?l0003o0000o`0;0000o`03020Po`3_kol0oooo00h0oooo00<0c<co0000o`000?l02P000?l001H0
003o00<0Shoo0?ooo`3oool03`3oool80000o`030820o`3oool0oooo00d0oooo00<0@43o0000o`00
0?l020000?l?0?ooo`030;noo`000?l0003o00H0003o00<0@43o0?ooo`3oool0;`3oool00`20P?l0
003o0000o`060000o`030820o`3oool0oooo00d0oooo00<0@43o0000o`000?l030000?l00`10@?l0
oooo0?ooo`0>0?ooo``0003o000F0000o`030820o`3oool0oooo00l0oooo20000?l00`20P?l0oooo
0?ooo`0=0?ooo`030410o`000?l0003o00P0003o3`3oool00`2o_ol0003o0000o`060000o`030410
o`3oool0oooo02l0oooo00<0P83o0000o`000?l01P000?l00`20P?l0oooo0?ooo`0=0?ooo`030410
o`000?l0003o00d0003o00<0c<co0?ooo`3oool03@3oool00`10@?l0003o0000o`090000o`005P00
0?l00`20P?l0oooo0?ooo`0>0?ooo`030>o_o`000?l0003o00H0003o00<0P83o0?ooo`3oool03@3o
ool00`10@?l0003o0000o`080000o`l0oooo00<0_koo0000o`000?l01P000?l00`10@?l0oooo0?oo
o`0_0?ooo`030820o`000?l0003o00H0003o00<0P83o0?ooo`3oool03@3oool00`10@?l0003o0000
o`0=0000o`03071`o`3oool0oooo00d0oooo00<0@43o0000o`000?l02@000?l001H0003o00<0c<co
0?ooo`3oool03P3oool00`2o_ol0003o0000o`060000o`030820o`3oool0oooo00d0oooo00<0@43o
0000o`000?l020000?l?0?ooo`030;noo`000?l0003o00H0003o00<0@43o0?ooo`3oool0;`3oool0
0`20P?l0003o0000o`060000o`030820o`3oool0oooo00d0oooo00<0@43o0000o`000?l03@000?l0
0`10@?l0oooo0?ooo`0=0?ooo`0306IVo`000?l0003o00T0003o000E0000o`03020Po`3oool0oooo
00l0oooo00<0Shoo0000o`000?l01P000?l00`20P?l0oooo0?ooo`0=0?ooo`030410o`000?l0003o
00P0003o3`3oool00`2o_ol0003o0000o`060000o`030410o`3oool0oooo02l0oooo00<0P83o0000
o`000?l01P000?l00`20P?l0oooo0?ooo`0=0?ooo`030410o`000?l0003o00d0003o00<0<c?o0?oo
o`3oool03@3oool00`20P?l0003o0000o`090000o`005@000?l00`2_[ol0oooo0?ooo`0?0?ooo`03
051@o`000?l0003o00H0003o00<0P83o0?ooo`3oool03@3oool00`10@?l0003o0000o`080000o`l0
oooo00<0_koo0000o`000?l01P000?l00`10@?l0oooo0?ooo`0_0?ooo`030820o`000?l0003o00H0
003o00<0P83o0?ooo`3oool03@3oool00`10@?l0003o0000o`0=0000o`03020Po`3oool0oooo00d0
oooo00<0P83o0000o`000?l02@000?l001@0003o00<0@43o0?ooo`3oool0403oool90000o`030820
o`3oool0oooo00d0oooo00<0@43o0000o`000?l020000?l?0?ooo`030;noo`000?l0003o00H0003o
00<0@43o0?ooo`3oool0;`3oool00`20P?l0003o0000o`060000o`03071`o`3oool0oooo00d0oooo
00<0L73o0000o`000?l03@000?l00`10@?l0oooo0?ooo`0=0?ooo`030820o`000?l0003o00T0003o
000D0?ooo`03020Po`000?l0003o00l0003o00<0IVKo0?ooo`3oool01`3oool00`20P?l0003o0000
o`0=0000o`030;noo`3oool0oooo00P0oooo3`000?l00`10@?l0oooo0?ooo`060?ooo`030;noo`00
0?l0003o02l0003o00<0P83o0?ooo`3oool01P3oool00`2o_ol0003o0000o`0=0000o`0306IVo`3o
ool0oooo00d0oooo00<0Shoo0000o`000?l03@000?l00`2_[ol0oooo0?ooo`090?ooo`004`3oool0
0`1`L?l0003o0000o`0@0000o`030;noo`3oool0oooo00L0oooo00<0VIWo0000o`000?l03@000?l0
0`2o_ol0oooo0?ooo`080?ooo`l0003o00<0P83o0?ooo`3oool01P3oool00`2o_ol0003o0000o`0_
0000o`030820o`3oool0oooo00H0oooo00<0_koo0000o`000?l03@000?l00`0P8?l0oooo0?ooo`0=
0?ooo`03051@o`000?l0003o00d0003o00<0_koo0?ooo`3oool02@3oool00180oooo00<0_koo0000
o`000?l040000?l00`10@?l0oooo0?ooo`080?ooo`030;noo`000?l0003o00d0003o00<0P83o0?oo
o`3oool01`3oool00`2_[ol0003o0000o`0=0000o`030820o`3oool0oooo00H0oooo00<0_koo0000
o`000?l0;`000?l00`20P?l0oooo0?ooo`070?oooa00003o00<0VIWo0?ooo`3oool02`3oool00`3O
gol0003o0000o`0>0000o`030>o_o`3oool0oooo00T0oooo000B0?ooo`03020Po`000?l0003o0100
003o00<0gmoo0?ooo`3oool0203oool00`2o_ol0003o0000o`0=0000o`030410o`3oool0oooo00L0
oooo00<0IVKo0000o`000?l03@000?l00`20P?l0oooo0?ooo`060?ooo`030;noo`000?l0003o02l0
003o00<0P83o0?ooo`3oool01`3oool00`0P8?l0003o0000o`0=0000o`03010@o`3oool0oooo00/0
oooo00<0<c?o0000o`000?l03@000?l00`0P8?l0oooo0?ooo`0:0?ooo`004@3oool00`20P?l0003o
0000o`0@0000o`03071`o`3oool0oooo00T0oooo00<0gmoo0000o`000?l03P000?l00`2o_ol0oooo
0?ooo`050?ooo`030=oOo`0@4?l0003o00h0003o00<0VIWo0?ooo`3oool01P3oool00`2o_ol0003o
0000o`0_0000o`030820o`3oool0oooo00L0oooo00<0D53o0000o`000?l03P000?l00`0c<ol0gmoo
0?ooo`090?ooo`0306IVo`000?l0003o00h0003o00<0IVKo0?ooo`3oool02P3oool00100oooo00<0
c<co0000o`000?l040000?l00`0@4?l0knoo0?ooo`0;0?oooa00003o00<0823o0<c<o`3oool01@3o
ool00`0c<ol0003o0000o`0>0000o`030;noo`3oool0oooo00H0oooo00<0_koo0000o`000?l0;`00
0?l00`20P?l0oooo0?ooo`070?ooo`0309VIo`000?l0003o00l0003o00<0413o09VIo`3oool01P3o
ool00`2o_ol0<c?o0000o`0@0000o`0309VIo`3oool0oooo00X0oooo000@0?ooo`0303<co`000?l0
003o0100003o00<0[joo0?ooo`3oool02`3oool00`10@?l0003o0000o`0>0000o`03010@o`1`L?l0
[joo0080_koo00<0L73o010@o`000?l040000?l90?ooo`030;noo`000?l0003o02l0003o00<0P83o
0?ooo`3oool01`3oool00`3_kol0003o0000o`0A0000o`04010@o`1VI_l0P83o09VIo`80P83o00<0
<c?o0000o`000?l04@000?l00`3_kol0oooo0?ooo`0:0?ooo`003`3oool00`2?Sol0003o0000o`0@
0000o`030410o`3oool0oooo00`0oooo00<0P83o0000o`000?l09@000?l00`10@?l0oooo0?ooo`07
0?ooo`030;noo`000?l0003o00l0003o3`3oool00`10@?l0003o0000o`0>0000o`030820o`3oool0
oooo00P0oooo00<0D53o0000o`000?l0:@000?l00`1VI_l0oooo0?ooo`0;0?ooo`003`3oool00`0@
4?l0003o0000o`0?0000o`03010@o`3Ogol0oooo00d0oooo00<0c<co0000o`000?l09@000?l00`2?
Sol0oooo0?ooo`070?ooo`030;noo`000?l0003o00l0003o3`3oool00`10@?l0003o0000o`0>0000
o`030820o`3oool0oooo00P0oooo00<0_koo0000o`000?l0:@000?l00`2o_ol0oooo0?ooo`0;0?oo
o`003P3oool00`20P?l0003o0000o`0@0000o`0308n?o`3oool0oooo00h0oooo00<0823o0000o`00
0?l08`000?l00`0@4?l0knoo0?ooo`080?ooo`030;noo`000?l0003o00l0003o3`3oool00`10@?l0
003o0000o`0>0000o`030820o`3oool0oooo00T0oooo00<0<c?o0000o`000?l09`000?l00`10@?l0
oooo0?ooo`0<0?ooo`003P3oool00`0@4?l0003o0000o`0?0000o`0303<co`3oool0oooo00l0oooo
00<0VIWo0000o`000?l08`000?l00`1VI_l0oooo0?ooo`080?ooo`030;noo`000?l0003o00l0003o
3`3oool00`10@?l0003o0000o`0>0000o`030820o`3oool0oooo00T0oooo00<0_koo0000o`000?l0
9`000?l00`3<c?l0oooo0?ooo`0<0?ooo`003@3oool00`2IVOl0003o0000o`0@0000o`030;noo`3o
ool0oooo0100oooo00<0823o0000o`000?l08P000?l00`3Ogol0oooo0?ooo`080?ooo`030;noo`00
0?l0003o00l0003o3`3oool00`10@?l0003o0000o`0>0000o`030820o`3oool0oooo00X0oooo00<0
L73o0000o`000?l09@000?l00`1`L?l0oooo0?ooo`0=0?ooo`003@3oool00`0P8?l0003o0000o`0?
0000o`0306IVo`3oool0oooo0140oooo00<0VIWo0000o`000?l08@000?l00`20P?l0oooo0?ooo`09
0?ooo`030;noo`000?l0003o00l0003o3`3oool00`10@?l0003o0000o`0>0000o`030820o`3oool0
oooo00X0oooo00<0knoo03<co`000?l090000?l00`0c<ol0knoo0?ooo`0>0?ooo`00303oool00`3<
c?l0003o0000o`0?0000o`03010@o`3_kol0oooo01<0oooo00<0@43o0000o`000?l07`000?l00`0c
<ol0knoo0?ooo`0:0?ooo`030;noo`000?l0003o00l0003o3`3oool00`10@?l0003o0000o`0>0000
o`030820o`3oool0oooo00/0oooo00<0c<co010@o`000?l08P000?l00`0@4?l0c<co0?ooo`0?0?oo
o`00303oool00`2?Sol0003o0000o`0?0000o`03071`o`3oool0oooo01<0oooo00<0knoo010@o`00
0?l07P000?l00`0@4?l0c<co0?ooo`0;0?ooo`030;noo`000?l0003o00l0003o3`3oool00`10@?l0
003o0000o`0>0000o`0308n?o`3oool0oooo00`0oooo00<0_koo0000o`000?l08@000?l00`2_[ol0
oooo0?ooo`0?0?ooo`00303oool00`10@?l0003o0000o`0?0000o`030=oOo`3oool0oooo01@0oooo
00<0c<co010@o`000?l07@000?l00`2IVOl0oooo0?ooo`0;0?ooo`030;noo`000?l0003o00l0003o
3`3oool00`10@?l0003o0000o`0>0000o`030;noo`3oool0oooo00d0oooo00<0VIWo010@o`000?l0
7`000?l00`2IVOl0oooo0?ooo`0@0?ooo`00303ooolA0000o`0303<co`3oool0oooo01H0oooo00<0
c<co010@o`000?l06`000?l00`2IVOl0oooo0?ooo`0<0?ooo`030>o_o`000?l0003o00l0003o00<0
knoo0?ooo`3oool0303oool00`0@4?l0003o0000o`0>0000o`030;noo`3oool0oooo00h0oooo00<0
c<co010@o`000?l070000?l00`0@4?l0_koo0?ooo`0B0?ooo`002`3oool00`3Ogol0003o0000o`0?
0000o`030820o`3oool0oooo01L0oooo00<0c<co03<co`000?l060000?l00`0@4?l0_koo0?ooo`0?
0?oooa40003o00<0_koo0?ooo`3oool02`3oool00`3_kol0003o0000o`0?0000o`030;noo`3oool0
oooo00l0oooo00<0gmoo0410o`000?l06P000?l00`0c<ol0gmoo0?ooo`0C0?ooo`002`3oool00`2o
_ol0003o0000o`0?0000o`030820o`3oool0oooo01P0oooo00<0knoo06IVo`000?l05P000?l00`10
@?l0gmoo0?ooo`0@0?ooo`03010@o`000?l0003o00h0003o00<0L73o0?ooo`3oool02`3oool00`2_
[ol0003o0000o`0?0000o`030=oOo`3oool0oooo0140oooo00<0Shoo010@o`000?l05P000?l00`0@
4?l0Ogoo0?ooo`0E0?ooo`002`3oool00`2o_ol0003o0000o`0?0000o`030820o`3oool0oooo01X0
oooo00<0_koo03<co`000?l04P000?l00`0P8?l0VIWo0?ooo`0B0?ooo`030410o`000?l0003o00h0
003o00<0413o0>o_o`3oool02`3oool00`10@?l0003o0000o`0?0000oaD0oooo00<0knoo06IVo`00
0?l050000?l00`1VI_l0gmoo0?ooo`0F0?ooo`002`3oool00`2o_ol0003o0000o`0?0000o`030410
o`3oool0oooo01`0oooo00<0_koo051@o`000?l03P000?l00`0c<ol0VIWo0?ooo`0D0?ooo`03071`
o`000?l0003o00l0003o00<0D53o0?ooo`3oool02@3oool00`2IVOl0003o0000o`0?0000o`0303<c
o`3oool0oooo01D0oooo00<0gmoo07moo`0P8?l03`000?l00`0P8?l0Ogoo0=oOo`0I0?ooo`002`3o
ool00`2o_ol0003o0000o`0@0000o`030;noo`3oool0oooo01d0oooo00@0knoo09VIo`1VI_l0<c?o
1`000?l0100P8?l0D53o08n?o`3OgolG0?ooo`0309VIo`000?l0003o0100003o00<0IVKo0?ooo`3o
ool01`3oool00`2IVOl0003o0000o`0@0000o`0306IVo`3oool0oooo01P0oooo00@0c<co08n?o`10
@?l0823o1`000?l0100P8?l0D53o07moo`3<c?lL0?ooo`002`3oool00`2o_ol0003o0000o`0@0000
o`03010@o`2o_ol0oooo02<0oooo00@0c<co0;noo`2o_ol0gmoo703oool00`3Ogol0003o0000o`0A
0000o`03020Po`2_[ol0oooo00@0oooo00<0gmoo06IVo`000?l04P000?l00`2IVOl0oooo0?ooo`0N
0?ooo`<0_koo00<0gmoo0?ooo`3oool07`3oool000`0oooo50000?l00`1VI_l0[joo0?ooo`030?oo
o`030;noo`1`L?l0c<co03`0oooo00<0823o0000o`000?l04P000?l01@0@4?l0@43o0410o`10@?l0
823o01D0003o00<0gmoo0?ooo`3oool0@`3oool000`0oooo00<0823o0000o`000?l06@000?l00`2o
_ol0oooo0?ooo`0j0?ooo`03071`o`000?l0003o02/0003o00<0@43o0?ooo`3oool0A03oool000`0
oooo00<0IVKo0000o`000?l06@000?l00`2o_ol0oooo0?ooo`0j0?ooo`030=oOo`000?l0003o02/0
003o00<0VIWo0?ooo`3oool0A03oool000`0oooo00<0[joo0000o`000?l06@000?l00`2o_ol0oooo
0?ooo`0k0?ooo`03051@o`000?l0003o02T0003o00<0823o0?ooo`3oool0A@3oool000d0oooo00<0
413o0000o`000?l060000?l00`2o_ol0oooo0?ooo`0k0?ooo`030;noo`000?l0003o02T0003o00<0
VIWo0?ooo`3oool0A@3oool000d0oooo00<0P83o0000o`000?l060000?l00`2o_ol0oooo0?ooo`0l
0?ooo`0306IVo`000?l0003o02L0003o00<0<c?o0?ooo`3oool0AP3oool000d0oooo00<0gmoo010@
o`000?l060000?l00`2o_ol0oooo0?ooo`0l0?ooo`030>o_o`0@4?l0003o02L0003o00<0c<co0?oo
o`3oool0AP3oool000h0oooo00<0P83o0000o`000?l05`000?l00`2o_ol0oooo0?ooo`0m0?ooo`03
0;noo`000?l0003o02D0003o00<0Shoo0?ooo`3oool0A`3oool000l0oooo00<0<c?o0000o`000?l0
5P000?l00`2o_ol0oooo0?ooo`0n0?ooo`0309VIo`000?l0003o02<0003o00<0IVKo0?ooo`3oool0
B03oool000l0oooo00<0c<co010@o`000?l05P000?l00`2o_ol0oooo0?ooo`0o0?ooo`03071`o`00
0?l0003o0240003o00<0<c?o0?ooo`3oool0B@3oool00100oooo00<0_koo0000o`000?l05@000?l0
0`2o_ol0oooo0?ooo`100?ooo`0306IVo`000?l0003o01l0003o00<0<c?o0>o_o`3oool0BP3oool0
0140oooo00<0VIWo010@o`000?l050000?l00`2o_ol0oooo0?ooo`110?ooo`0309VIo`000?l0003o
01d0003o00<0IVKo0>o_o`3oool0B`3oool00180oooo00<0c<co020Po`000?l04`000?l00`2o_ol0
oooo0?ooo`120?ooo`030;noo`0P8?l0003o01/0003o00<0Ogoo0?ooo`3oool0C03oool001<0oooo
00<0knoo06IVo`000?l04P000?l00`2o_ol0oooo0?ooo`130?ooo`030>o_o`1VI_l0003o01P0003o
00<0<c?o0<c<o`3oool0CP3oool001D0oooo00<0_koo0410o`000?l040000?l00`2o_ol0oooo0?oo
o`150?ooo`030<c<o`10@?l0003o01@0003o00<0823o09VIo`3oool0D03oool001L0oooo00<0_koo
051@o`000?l03P000?l00`2o_ol0oooo0?ooo`170?ooo`030<c<o`1VI_l0413o0100003o00<0D53o
0:n_o`3oool0DP3oool001T0oooo00@0knoo0:n_o`1VI_l0@43o20000?l0100@4?l0@43o07moo`3O
gom<0?ooo`040;noo`1oOol0@43o010@o`P0003o00@0@43o071`o`2_[ol0knooE@3oool001h0oooo
00<0knoo0;noo`2o_ol00`2o_omF0?ooo`030<c<o`2o_ol0_koo0080_koo00<0knoo0?ooo`3oool0
F03oool00001\
\>"],
            ImageRangeCache->{{{0, 217}, {87, 0}} -> {-0.00108501, 0.999385, 
            1.00001, 
            1.00001}}], \(This\ package\ includes\ routines\ which\ provide\ \
SNAP\ functionalities . \ 
              The\ version\ of\ this\ package\ is\ 0.2  .4\ and\ implemented\ \
by\ Kosaku\ \(\(NAGASAKA\)\(.\)\)\)}
        },
      RowAlignments->Top,
      ColumnAlignments->{Right, Left}]]]], "DefinitionBox",
  GeneratedCell->True,
  CellAutoOverwrite->True,
  Background->GrayLevel[1]],

Cell[BoxData[
    \("This package includes routines which export Mathematica's Graphics \
into FLASH format, implemented by Kosaku NAGASAKA."\)], "Print",
  CellLabel->"\\:6B21\\:3088\\:308A\\:FF1AIn[1]:="],

Cell[TextData[{
  "This gives a SNAP structure. The output looks like a normal expression. \
Note that using machine precision numbers in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " sometimes is risky because the product of a machine precisions number and \
a arbitray precisions number has always machine precisions. Hence, in the \
below, we does not use machine precisions numbers."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(g = 
      SNAP[1.`16\ x^5 + 5.503`16\ x^4 + 9.765`16\ x^3 + 7.647`16\ x^2 + 
          2.762`16\ x + 0.37725`16]\)], "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[
    \(\(\(0.37725`\)\(\[InvisibleSpace]\)\) + 2.762`\ x + 7.647`\ x\^2 + 
      9.765`\ x\^3 + 5.503`\ x\^4 + x\^5\)], "Output",
  CellLabel->"Out[2]="]
}, Open  ]],

Cell[TextData[{
  "This gives the ",
  ButtonBox["FullForm",
    ButtonStyle->"RefGuideLink"],
  " of the above SNAP structure."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FullForm[g]\)], "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[
    TagBox[
      StyleBox[\(SNAP[
          Plus[Rational[1509, 4000], Times[Rational[1381, 500], x], 
            Times[Rational[7647, 1000], Power[x, 2]], 
            Times[Rational[1953, 200], Power[x, 3]], 
            Times[Rational[5503, 1000], Power[x, 4]], Power[x, 5]], 
          1.388833339758600409374164608968865`14.403201466246212*^-15, 
          List[List[x, 5]], AbsolutePolynomial2Norm]\),
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True],
      FullForm]], "Output",
  CellLabel->"Out[3]//FullForm="]
}, Open  ]],

Cell[TextData[{
  "The error bound of this SNAP structure, a set of polynomials is given by \
",
  StyleBox["Tolerance",
    FontFamily->"Courier"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Tolerance[g]\)], "Input",
  CellLabel->"In[4]:="],

Cell[BoxData[
    \(1.388833339758600409374164608968865`14.403201466246212*^-15\)], "Output",\

  CellLabel->"Out[4]="]
}, Open  ]],

Cell["Each calculation enlarges its error bound as follows.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(g2 = g*g\)], "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    \(\((\(\(0.37725`\)\(\[InvisibleSpace]\)\) + 2.762`\ x + 7.647`\ x\^2 + \
9.765`\ x\^3 + 5.503`\ x\^4 + x\^5)\)\^2\)], "Output",
  CellLabel->"Out[5]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Tolerance[g2]\)], "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[
    \(9.449435996086558768912085`14.403201466246216*^-14\)], "Output",
  CellLabel->"Out[6]="]
}, Open  ]],

Cell[TextData[{
  "By ",
  StyleBox["Element",
    FontFamily->"Courier"],
  ", we can check whether a polynomial is included in the given SNAP \
structure or not. The error bound of the below SNAP structure is about ",
  Cell[BoxData[
      \(1.38883\[Times]10\^\(-15\)\)]],
  ", hence we have the following results."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Element[Normal[g] + 1.2`16*^-15, g]\)], "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[7]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Element[Normal[g] + 1.5`16*^-15, g]\)], "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[
    \(False\)], "Output",
  CellLabel->"Out[8]="]
}, Open  ]],

Cell[TextData[{
  "In the above, ",
  StyleBox["Normal",
    FontFamily->"Courier"],
  " gives corresponding representative polynomials in the normal form."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Normal[g] // FullForm\)], "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[
    TagBox[
      StyleBox[\(Plus[Rational[1509, 4000], Times[Rational[1381, 500], x], 
          Times[Rational[7647, 1000], Power[x, 2]], 
          Times[Rational[1953, 200], Power[x, 3]], 
          Times[Rational[5503, 1000], Power[x, 4]], Power[x, 5]]\),
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True],
      FullForm]], "Output",
  CellLabel->"Out[9]//FullForm="]
}, Open  ]],

Cell["\<\
We can expand the expression of the representative polynomial of a \
SNAP structure.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Expand[g2]\)], "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    \(\(\(0.1423175625`\)\(\[InvisibleSpace]\)\) + 2.083929`\ x + 
      13.3983055`\ x\^2 + 49.6097205`\ x\^3 + 116.5704825`\ x\^4 + 
      180.498982`\ x\^5 + 185.042107`\ x\^6 + 122.76759`\ x\^7 + 
      49.813009`\ x\^8 + 11.006`\ x\^9 + x\^10\)], "Output",
  CellLabel->"Out[10]="]
}, Open  ]],

Cell["\<\
Any result of a substitution for a SNAP structure has also a \
guaranteed accuracy.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(g3 = g2 /. x -> 1\)], "Input",
  CellLabel->"In[11]:="],

Cell[BoxData[
    \(731.9324430624999999999999999973`14.847672424864392\)], "Output",
  CellLabel->"Out[11]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Tolerance[g3]\)], "Input",
  CellLabel->"In[12]:="],

Cell[BoxData[
    \(1.03943795956956296505578855`14.513801222004547*^-12\)], "Output",
  CellLabel->"Out[12]="]
}, Open  ]],

Cell["\<\
Moreover, we show a situation argued in the last of the subsection \
\[OpenCurlyDoubleQuote]Tolerance Mechanisms\[CloseCurlyDoubleQuote].\
\>", \
"Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(g\)], "Input",
  CellLabel->"In[13]:="],

Cell[BoxData[
    \(\(\(0.37725`\)\(\[InvisibleSpace]\)\) + 2.762`\ x + 7.647`\ x\^2 + 
      9.765`\ x\^3 + 5.503`\ x\^4 + x\^5\)], "Output",
  CellLabel->"Out[13]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(g - x^5\)], "Input",
  CellLabel->"In[15]:="],

Cell[BoxData[
    \(SNAP::"invalid" \(\(:\)\(\ \)\) 
      "Tolerance is larger than the representing leading coefficient: \!\(0.`\
\) \[LessEqual] \!\(1.3888333397586004`*^-15\)."\)], "Message",
  CellLabel->"\\:6B21\\:3088\\:308A\\:FF1AIn[15]:="],

Cell[BoxData[
    \(\(\(0.37725`\)\(\[InvisibleSpace]\)\) + 2.762`\ x + 7.647`\ x\^2 + 
      9.765`\ x\^3 + 5.503`\ x\^4\)], "Output",
  CellLabel->"Out[15]="]
}, Open  ]],

Cell["\<\
This rewriting can be an important information for users, so this \
package generates the above warning.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Mathematical Background", "Section",
  ShowCellBracket->True],

Cell[CellGroupData[{

Cell["Tolerance Mechanisms", "Subsection"],

Cell[TextData[{
  "We introduce the following data structures for empirical polynomials. They \
are very simple but there is no system in which we can use the following \
structures unconsciously like as ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s floating-point numbers or Kako and Sasaki's effective floating-point \
numbers [KS97]. The following data structures are different from that of the \
previous version of this package [Nag04a, Nag04b]. This version become to be \
able to operate polynomials which have more than 2 variables (bivariate or \
multivariate polynomials)."
}], "Text"],

Cell["Definition 1 (SNAP structures)", "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  "We define the following SNAP structures (like sets of neighbors) for \
approximate polynomials, for the given polynomial ",
  Cell[BoxData[
      \(TraditionalForm\`f(u\_1, \[Ellipsis], \ 
          u\_r)\  \[Element] \ \[DoubleStruckCapitalC][u\_1, \ \[Ellipsis], \ 
          u\_r]\)]],
  " and tolerance ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\  \[Element] \ \
\[DoubleStruckCapitalR]\)]],
  "."
}], "Text",
  CellMargins->{{87, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(TextForm\`\(\(\(P\_2\) \((f, \ \[Epsilon])\) = {f\&_ | 
          f\&_ \[Element] \[DoubleStruckCapitalC][u\_1, \ \[Ellipsis], \ 
              u\_r], \ \(deg\_u\) f\&_ = \(deg\_u\) 
            f\ \((\[ForAll] u \[Element] {u\_1, \ \[Ellipsis], \ 
                    u\_r})\), \ \(\(\[DoubleVerticalBar]\)\(f - 
            f\&_\)\( \[DoubleVerticalBar] \_2\)\(\[LessEqual]\)\(\[Epsilon]\)\
\)}\)\(,\)\)\)], "NumberedEquation",
  CellMargins->{{103, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(TextForm\`\(\(\(P\_1\) \((f, \ \[Epsilon])\) = {f\&_ | 
          f\&_ \[Element] \[DoubleStruckCapitalC][u\_1, \ \[Ellipsis], \ 
              u\_r], \ \(deg\_u\) f\&_ = \(deg\_u\) 
            f\ \((\[ForAll] u \[Element] {u\_1, \ \[Ellipsis], \ 
                    u\_r})\), \ \(\(\[DoubleVerticalBar]\)\(f - 
            f\&_\)\( \[DoubleVerticalBar] \_1\)\(\[LessEqual]\)\(\[Epsilon]\)\
\)}\)\(,\)\)\)], "NumberedEquation",
  CellMargins->{{103, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(TextForm\`\(P\_\[Infinity]\) \((f, \ \[Epsilon])\) = \(\({f\&_ | 
            f\&_ \[Element] \[DoubleStruckCapitalC][u\_1, \ \[Ellipsis], \ 
                u\_r], \ \(deg\_u\) f\&_ = \(deg\_u\) 
              f\ \((\[ForAll] u \[Element] {u\_1, \ \[Ellipsis], \ 
                      u\_r})\), \ \(\(\[DoubleVerticalBar]\)\(f - 
              f\&_\)\( \[DoubleVerticalBar] \_\[Infinity]\)\(\[LessEqual]\)\(\
\[Epsilon]\)\)}\)\(.\)\)\)], "NumberedEquation",
  CellMargins->{{103, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[DoubleVerticalBar]\)\(f\)\( \
\[DoubleVerticalBar] \_p\)\)\)]],
  " denotes coefficients vector norms for polynomials: "
}], "Text",
  CellMargins->{{87, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(TextForm\`\(\(\[DoubleVerticalBar]\)\(f\)\( \[DoubleVerticalBar] \
\_p\)\) = \((\[CapitalSigma]\_i | f\_i\( | \^p\))\)\^\(1\/p\), \ 
    f = \(\[CapitalSigma]\_i\) \(f\_i\) \(u\_1\%\(e\_i1\)\) \[CenterEllipsis]\
\ \(\(u\_r\%\(e\_ir\)\)\(.\)\)\)], "NumberedEquation",
  CellMargins->{{103, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "In the rest of this notebook, ",
  Cell[BoxData[
      \(TraditionalForm\`\(P\_*\)(f, \[Epsilon])\)]],
  " means any of ",
  Cell[BoxData[
      \(TraditionalForm\`\(P\_2\)(f, \[Epsilon])\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(P\_1\)(f, \[Epsilon])\)]],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`\(P\_\[Infinity]\)(f, \[Epsilon])\)]],
  "."
}], "Text"],

Cell["Remark 1", "Text",
  FontWeight->"Bold"],

Cell["\<\
One may think that the following definition is better than the \
above definition.\
\>", "Text",
  CellMargins->{{87, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(TextForm\`\(\(\(P\_*\) \((f, \ \[Epsilon])\) = {f\&_ | 
          f\&_ \[Element] \[DoubleStruckCapitalC][u\_1, \ \[Ellipsis], \ 
              u\_r], \ \(deg\_u\) f\&_ \[LessEqual] \(deg\_u\) 
            f\ \((\[ForAll] u \[Element] {u\_1, \ \[Ellipsis], \ 
                    u\_r})\), \ \(\(\[DoubleVerticalBar]\)\(f - 
            f\&_\)\( \[DoubleVerticalBar] \_*\)\(\[LessEqual]\)\(\[Epsilon]\)\
\)}\)\(,\)\)\)], "NumberedEquation",
  CellMargins->{{103, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "However, this definition poses strange situations. For example, let ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)]],
  " be an arbitrary small positive real number and ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " be the following polynomial."
}], "Text",
  CellMargins->{{87, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(TextForm\`f = \(f\_n\) x\^n + \(f\_\(n - 1\)\) 
          x\^\(n - 1\) + \[CenterEllipsis] + \(f\_1\) x + f\_0, \ 
    f\_i \[Element] \[DoubleStruckCapitalC], \ \(\(|\)\(f\_n\)\(|\)\(\(\
\[LessEqual]\)\(\(\[Epsilon]\)\(.\)\)\)\)\)], "NumberedEquation",
  CellMargins->{{103, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "For this polynomial, ",
  Cell[BoxData[
      \(TraditionalForm\`\(P\_*\)(f, \[Epsilon])\)]],
  " includes polynomials which have ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " roots (counting multiplicities) and also polynomials which have at most \
",
  Cell[BoxData[
      \(TraditionalForm\`n - 1\)]],
  " roots. This causes terrible situations for algorithms, hence we use the \
expressions of Definition 1."
}], "Text",
  CellMargins->{{87, Inherited}, {Inherited, Inherited}}],

Cell["\<\
The coefficients vector norms for polynomials have similar \
properties of normal vector norms (see [GL96] if the reader would like to \
study those basic properties), hence we have the following corollary.\
\>", \
"Text"],

Cell["Corollary 1", "Text",
  FontWeight->"Bold"],

Cell["We have the following properties.", "Text",
  CellMargins->{{87, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(TextForm\`\(\(\(P\_2\) \((f, \ \[Epsilon])\) \[SubsetEqual] \(P\_1\) \
\((f, \ \[Epsilon] \@\(\( \[CapitalPi]\_\(i = 1\)\%r\) \((e\_i + \
1)\)\))\)\)\(,\)\)\)], "NumberedEquation",
  CellMargins->{{103, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(TextForm\`\(\(\(P\_2\) \((f, \ \[Epsilon])\) \[SubsetEqual] \(P\_\
\[Infinity]\) \((f, \ \[Epsilon])\)\)\(,\)\)\)], "NumberedEquation",
  CellMargins->{{103, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(TextForm\`\(\(\(P\_1\) \((f, \ \[Epsilon])\) \[SubsetEqual] \(P\_2\) \
\((f, \ \[Epsilon])\)\)\(,\)\)\)], "NumberedEquation",
  CellMargins->{{103, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(TextForm\`\(\(\(P\_1\) \((f, \ \[Epsilon])\) \[SubsetEqual] \(P\_\
\[Infinity]\) \((f, \ \[Epsilon])\)\)\(,\)\)\)], "NumberedEquation",
  CellMargins->{{103, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(TextForm\`\(\(\(P\_\[Infinity]\) \((f, \ \[Epsilon])\) \[SubsetEqual] \
\(P\_2\) \((f, \ \[Epsilon] \@\(\( \[CapitalPi]\_\(i = 1\)\%r\) \((e\_i + \
1)\)\))\)\)\(,\)\)\)], "NumberedEquation",
  CellMargins->{{103, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(TextForm\`\(\(\(P\_\[Infinity]\) \((f, \ \[Epsilon])\) \[SubsetEqual] \
\(P\_1\) \((f, \ \[Epsilon]\ \(\[CapitalPi]\_\(i = 1\)\%r\) \((e\_i + 
                1)\))\)\)\(,\)\)\)], "NumberedEquation",
  CellMargins->{{103, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`e\_i\)]],
  " denotes the degree of ",
  Cell[BoxData[
      \(TraditionalForm\`f(u\_1, \ \[Ellipsis], \ u\_r)\)]],
  " w.r.t. ",
  Cell[BoxData[
      \(TraditionalForm\`u\_i\)]],
  ".",
  Cell[BoxData[
      FormBox[Cell[""], TraditionalForm]]]
}], "Text",
  CellMargins->{{87, Inherited}, {Inherited, Inherited}}],

Cell["Lemma 1", "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  "We have the following properties, for polynomials ",
  Cell[BoxData[
      \(TraditionalForm\`f(u\_1, \ \[Ellipsis], \ u\_r)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`h(u\_1, \ \[Ellipsis], \ u\_r)\)]],
  "."
}], "Text",
  CellMargins->{{87, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(TextForm\`\[ForAll] f\&_ \[Element] \(P\_2\) \((f, \[Epsilon]\_f)\), \ \
\[ForAll] h\&_ \[Element] \(P\_2\) \((h, \[Epsilon]\_h)\), \
\[IndentingNewLine]f\&_\[Times]
        h\&_ \[Element] \(P\_2\) \((f\[Times]
            h, \(\@\(min {\(\[CapitalPi]\_\(i = 1\)\%r\) \((e\_i + 
                          1)\), \(\[CapitalPi]\_\(i = 1\)\%r\) \((d\_i + 
                          1)\)}\)\) \((\(\[DoubleVerticalBar]\)\(f\)\( \
\[DoubleVerticalBar] \
\_2\)\(\(\[Epsilon]\_h\)\(+\)\)\(\[DoubleVerticalBar]\)\(h\)\( \
\[DoubleVerticalBar] \_2\)\(\[Epsilon]\_f + \[Epsilon]\_f\ \
\[Epsilon]\_h\))\))\), \)], "NumberedEquation",
  CellMargins->{{103, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(TextForm\`\[ForAll] f\&_ \[Element] \(P\_1\) \((f, \[Epsilon]\_f)\), \ \
\[ForAll] h\&_ \[Element] \(P\_1\) \((h, \[Epsilon]\_h)\), \
\[IndentingNewLine]f\&_\[Times]
        h\&_ \[Element] \(P\_1\) \((f\[Times]
            h, \(\(\[DoubleVerticalBar]\)\(f\)\( \[DoubleVerticalBar] \_1\)\(\
\(\[Epsilon]\_h\)\(+\)\)\(\[DoubleVerticalBar]\)\(h\)\( \[DoubleVerticalBar] \
\_1\)\(\[Epsilon]\_f + \[Epsilon]\_f\ \[Epsilon]\_h\)\))\), \)], \
"NumberedEquation",
  CellMargins->{{103, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(TextForm\`\[ForAll] f\&_ \[Element] \(P\_\[Infinity]\) \((f, \[Epsilon]\
\_f)\), \ \[ForAll] h\&_ \[Element] \(P\_\[Infinity]\) \((h, \
\[Epsilon]\_h)\), \[IndentingNewLine]f\&_\[Times]
        h\&_ \[Element] \(P\_\[Infinity]\) \((f\[Times]h, 
          min {\(\[CapitalPi]\_\(i = 1\)\%r\) \((e\_i + 
                    1)\), \(\[CapitalPi]\_\(i = 1\)\%r\) \((d\_i + 
                    1)\)} \((\(\[DoubleVerticalBar]\)\(f\)\( \
\[DoubleVerticalBar] \
\_1\)\(\(\[Epsilon]\_h\)\(+\)\)\(\[DoubleVerticalBar]\)\(h\)\( \
\[DoubleVerticalBar] \_1\)\(\[Epsilon]\_f + \[Epsilon]\_f\ \
\[Epsilon]\_h\))\))\), \)], "NumberedEquation",
  CellMargins->{{103, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`e\_i\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`d\_i\)]],
  " denotes the degree of ",
  Cell[BoxData[
      \(TraditionalForm\`f(u\_1, \ \[Ellipsis], \ u\_r)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`h(u\_1, \ \[Ellipsis], \ u\_r)\)]],
  " w.r.t. ",
  Cell[BoxData[
      \(TraditionalForm\`u\_i\)]],
  ", respectively.",
  Cell[BoxData[
      FormBox[Cell[""], TraditionalForm]]]
}], "Text",
  CellMargins->{{87, Inherited}, {Inherited, Inherited}}],

Cell["Proof of Lemma 1", "Text",
  FontWeight->"Bold"],

Cell["\<\
The lemma is proved by the following properties of vector and \
matrix norms (see [GL96]), since any multiplication of polynomials can be \
done as matrix multiplications.\
\>", "Text",
  CellMargins->{{87, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(TextForm\`\(\(\(\[DoubleVerticalBar]\)\(A\)\( \[DoubleVerticalBar] \
\_2\)\(\[LessEqual]\)\(\[DoubleVerticalBar]\)\(A\)\( \[DoubleVerticalBar] \_F\
\)\)\(,\)\)\)], "NumberedEquation",
  CellMargins->{{103, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(TextForm\`\(\(\(\(\[DoubleVerticalBar]\)\(A\)\( \[DoubleVerticalBar] \
\_1\)\) = 
      max\_\(1 \[LessEqual] j \[LessEqual] n\)\[CapitalSigma]\_\(i = 1\)\%m | 
        a\_ij | \)\(,\)\)\)], "NumberedEquation",
  CellMargins->{{103, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(TextForm\`\(\(\(\(\[DoubleVerticalBar]\)\(A\)\( \[DoubleVerticalBar] \_\
\[Infinity]\)\) = 
      max\_\(1 \[LessEqual] i \[LessEqual] m\)\[CapitalSigma]\_\(j = 1\)\%n | 
        a\_ij | \)\(,\)\)\)], "NumberedEquation",
  CellMargins->{{103, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[DoubleVerticalBar]\)\(A\)\( \
\[DoubleVerticalBar] \_p\)\)\)]],
  " denotes matrix ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  "-norms for matrix ",
  Cell[BoxData[
      \(TraditionalForm\`A\)]],
  " of size ",
  Cell[BoxData[
      \(TraditionalForm\`m\[Times]n\)]],
  "."
}], "Text",
  CellMargins->{{87, Inherited}, {Inherited, Inherited}}],

Cell["Lemma 2", "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  "For polynomials ",
  Cell[BoxData[
      \(TraditionalForm\`f(u\_1, \ \[Ellipsis], \ u\_r)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`h(u\_1, \ \[Ellipsis], \ u\_r)\)]],
  ", if the following relation holds,"
}], "Text",
  CellMargins->{{87, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(TextForm\`\[ForAll] g\_f \[Element] \(P\_*\) \((f, \[Epsilon]\_f)\), \ \
\[ForAll] h\&_ \[Element] \(P\_*\) \((h, \[Epsilon]\_h)\), \(deg\_u\) \((g\_f \
+ h\&_)\) = 
      max {\(deg\_u\) f, \(deg\_u\) 
            h}\ \ \((\[ForAll] u \[Element] {u\_1, \ \[Ellipsis], \ 
                u\_r})\), \)], "NumberedEquation",
  CellMargins->{{103, Inherited}, {Inherited, Inherited}}],

Cell["we have the following properties.", "Text",
  CellMargins->{{87, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(TextForm\`\[ForAll] f\&_ \[Element] \(P\_2\) \((f, \[Epsilon]\_f)\), \ \
\[ForAll] h\&_ \[Element] \(P\_2\) \((h, \[Epsilon]\_h)\), \
\[IndentingNewLine]f\&_ + 
        h\&_ \[Element] \(P\_2\) \((f + 
              h, \[Epsilon]\_f + \[Epsilon]\_h)\) \[Congruent] {g | 
            g \[Element] \[DoubleStruckCapitalC][u\_1, \ \[Ellipsis], \ 
                u\_r], \ \(deg\_u\) g = 
            max {\(deg\_u\) f\&_, \(deg\_u\) 
                  h\&_}\ \ \((\[ForAll] u \[Element] {u\_1, \ \[Ellipsis], \ 
                      u\_r})\), \ \(\(\[DoubleVerticalBar]\)\(\((f + h)\) - 
              g\)\( \[DoubleVerticalBar] \_2\)\(\[LessEqual]\)\(\[Epsilon]\_f \
+ \[Epsilon]\_h\)\)}, \)], "NumberedEquation",
  CellMargins->{{103, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(TextForm\`\[ForAll] f\&_ \[Element] \(P\_1\) \((f, \[Epsilon]\_f)\), \ \
\[ForAll] h\&_ \[Element] \(P\_1\) \((h, \[Epsilon]\_h)\), \
\[IndentingNewLine]f\&_ + 
        h\&_ \[Element] \(P\_1\) \((f + 
              h, \[Epsilon]\_f + \[Epsilon]\_h)\) \[Congruent] {g | 
            g \[Element] \[DoubleStruckCapitalC][u\_1, \ \[Ellipsis], \ 
                u\_r], \ \(deg\_u\) g = 
            max {\(deg\_u\) f\&_, \(deg\_u\) 
                  h\&_}\ \ \((\[ForAll] u \[Element] {u\_1, \ \[Ellipsis], \ 
                      u\_r})\), \ \(\(\[DoubleVerticalBar]\)\(\((f + h)\) - 
              g\)\( \[DoubleVerticalBar] \_1\)\(\[LessEqual]\)\(\[Epsilon]\_f \
+ \[Epsilon]\_h\)\)}, \)], "NumberedEquation",
  CellMargins->{{103, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(TextForm\`\[ForAll] f\&_ \[Element] \(P\_\[Infinity]\) \((f, \[Epsilon]\
\_f)\), \ \[ForAll] h\&_ \[Element] \(P\_\[Infinity]\) \((h, \
\[Epsilon]\_h)\), \[IndentingNewLine]f\&_ + 
        h\&_ \[Element] \(P\_\[Infinity]\) \((f + 
              h, \[Epsilon]\_f + \[Epsilon]\_h)\) \[Congruent] {g | 
            g \[Element] \[DoubleStruckCapitalC][u\_1, \ \[Ellipsis], \ 
                u\_r], \ \(deg\_u\) g = 
            max {\(deg\_u\) f\&_, \(deg\_u\) 
                  h\&_}\ \ \((\[ForAll] u \[Element] {u\_1, \ \[Ellipsis], \ 
                      u\_r})\), \ \(\(\[DoubleVerticalBar]\)\(\((f + h)\) - 
              g\)\( \[DoubleVerticalBar] \_\[Infinity]\)\(\[LessEqual]\)\(\
\[Epsilon]\_f + \[Epsilon]\_h\)\)}, \)], "NumberedEquation",
  CellMargins->{{103, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`e\_i\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`d\_i\)]],
  " denotes the degree of ",
  Cell[BoxData[
      \(TraditionalForm\`f(u\_1, \ \[Ellipsis], \ u\_r)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`h(u\_1, \ \[Ellipsis], \ u\_r)\)]],
  " w.r.t. ",
  Cell[BoxData[
      \(TraditionalForm\`u\_i\)]],
  ", respectively.",
  Cell[BoxData[
      FormBox[Cell[""], TraditionalForm]]]
}], "Text",
  CellMargins->{{87, Inherited}, {Inherited, Inherited}}],

Cell["Proof of Lemma 2", "Text",
  FontWeight->"Bold"],

Cell["\<\
The lemma is directly proved by the norm's triangle inequality. \
\
\>", "Text",
  CellMargins->{{87, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "The condition of Lemma 2 is necessary for ensuring equalities for degrees \
in ",
  Cell[BoxData[
      \(TraditionalForm\`\(P\_*\)(f + h, \[Epsilon]\_f + \[Epsilon]\_h)\)]],
  ". Without the condition, strange situations as in Remark 1 may occur. \
However, for example, we have to operate with the following computation and \
determine the set ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  ". This is important especially for divisions (quotient and remainder) and \
reductions (for non-univariate polynomials)."
}], "Text"],

Cell[BoxData[
    \(TextForm\`\[ForAll] g \[Element] \(P\_*\) \((f, \[Epsilon])\), \ \
\[ForAll] h \[Element] \(P\_*\) \((f, \[Epsilon])\), \ 
    g - h \[Element] \(\(S\)\(.\)\)\)], "NumberedEquation",
  CellMargins->{{103, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "We introduce a simple rule to operate this. If the norm of the leading \
coefficients of the representative polynomial ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  ", w.r.t. ",
  Cell[BoxData[
      \(TraditionalForm\`u\_i\)]],
  ", is not larger than the tolerance ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)]],
  ", then we rewrite the SNAP structure as below."
}], "Text"],

Cell[BoxData[
    \(TextForm\`\(\(\(P\_*\) \((f, \[Epsilon])\)\  \[Implies] \ \(P\_*\) \((f\
\_new, \[Epsilon])\) = {g | 
          g \[Element] \[DoubleStruckCapitalC][u\_1, \ \[Ellipsis], \ 
              u\_r], \ \(deg\_u\) g = \(deg\_u\) 
            f\_new\ \((\[ForAll] u \[Element] {u\_1, \ \[Ellipsis], \ 
                    u\_r})\), \ \(\(\[DoubleVerticalBar]\)\(f\_new - 
            g\)\( \[DoubleVerticalBar] \_2\)\(\[LessEqual]\)\(\[Epsilon]\)\)}\
\)\(,\)\)\)], "NumberedEquation",
  CellMargins->{{103, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "where  ",
  Cell[BoxData[
      \(TraditionalForm\`f\_new\)]],
  " denotes ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(f\)\(-\)\)\)]],
  "(all the leading monomials of ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  ", w.r.t. ",
  Cell[BoxData[
      \(TraditionalForm\`u\_i\)]],
  ")."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Tolerance Implementations", "Subsection"],

Cell["\<\
According to the above mechanisms, we have implemented the \
structures, basic operations (addition and multiplication) on the structures, \
and functions which transform a structure into another.\
\>", "Text"],

Cell[TextData[{
  "We define the following expression to represent SNAP structures ",
  Cell[BoxData[
      \(TraditionalForm\`\(P\_2\)(f, \[Epsilon])\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(P\_1\)(f, \[Epsilon])\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(P\_\[Infinity]\)(f, \[Epsilon])\)]],
  ", where \[OpenCurlyDoubleQuote]scheme\[CloseCurlyDoubleQuote] can be ",
  StyleBox["AbsolutePolynomial2Norm",
    FontFamily->"Courier"],
  ", ",
  StyleBox["AbsolutePolynomial1Norm",
    FontFamily->"Courier"],
  " and ",
  StyleBox["AbsolutePolynomialiNorm",
    FontFamily->"Courier"],
  ", respectively. In the future release, other schemes will be implemented."
}], "Text"],

Cell[BoxData[
    \(SNAP[f, \[Epsilon], {{u\_1, e\_1}, \[Ellipsis], {u\_r, e\_r}}, 
      scheme]\)], "DefinitionBox"],

Cell["\<\
Using the above structure, we have implemented basic functions \
provided by the mechanisms. We show some of their expressions. We note that \
the package also provides functions which transform the given polynomial to \
the above representation automatically.\
\>", "Text"],

Cell[BoxData[
    \(TransformSNAP[
        SNAP[f_, epsf_, {{x_Symbol, n_}, yz___}, AbsolutePolynomial2Norm], 
        AbsolutePolynomialiNorm] := 
      SNAP[f, epsf, {{x, n}, yz}, AbsolutePolynomialiNorm]\)], "Input",
  Evaluatable->False],

Cell[BoxData[
    \(Normal[SNAP[f_, epsf_, {{x_Symbol, n_}, yz___}, scheme_]] := 
      f\)], "Input",
  Evaluatable->False],

Cell[BoxData[
    \(SNAP /: \(-SNAP[f_, epsf_, {{x_Symbol, n_}, yz___}, scheme_]\) := 
      SNAP[\(-f\), epsf, {{x, n}, yz}, scheme]\)], "Input",
  Evaluatable->False],

Cell[BoxData[
    \(SNAP[g_, epsg_, varsg_List, scheme_] + 
        SNAP[h_, epsh_, varsh_List, scheme_] ^:= 
      SNAP[g + h, epsg + epsh, maxvarslist[varsg, varsh], scheme]\)], "Input",\

  Evaluatable->False],

Cell[BoxData[
    \(SNAP[g_, epsg_, varsg_, scheme_] + f_?NotSNAPQ ^:= 
      SNAP[g, epsg, varsg, scheme] + SNAP[f]\)], "Input",
  Evaluatable->False],

Cell[BoxData[
    \(Tolerance[SNAP[f_, epsf_, vars_, scheme_]] := epsf\)], "Input",
  Evaluatable->False],

Cell[TextData[{
  "One of aims of the package is providing an environment in which we use \
SNAP structures transparently like ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s floating-point numbers, hence we have implemented the following ",
  StyleBox["Format",
    FontFamily->"Courier"],
  " code."
}], "Text",
  CellMargins->{{Inherited, Inherited}, {Inherited, 12}}],

Cell[BoxData[
    \(Format[SNAP[f_, e_, variables_, scheme_]] := N@f\)], "Input",
  Evaluatable->False]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Other Basic Operations", "Chapter"],

Cell["\<\
We implemented other basic operations: a polynomial division \
(quotient and remainder), reductions (for non-univariate polynomials) and a \
root finding with error considerations.\
\>", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {Cell["function"], Cell["purpose"]},
          {
            StyleBox["NSolve",
              
              FontFamily->
                "Courier"], \(finds\ numerical\ roots\ with\ error\ \
\(\(considerations\)\(.\)\)\)},
          {
            StyleBox["PolynomialQuotient",
              FontFamily->"Courier"], 
            RowBox[{"computes", " ", 
              StyleBox["a",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], " ", "polynomial", " ", "quotient", " ",
               "as", " ", 
              StyleBox["a",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], " ", "SNAP", 
              " ", \(\(structure\)\(.\)\)}]},
          {
            StyleBox["PolynomialRemainder",
              FontFamily->"Courier"], 
            RowBox[{"computes", " ", 
              StyleBox["a",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], " ", "polynomial", " ", "remainder", 
              " ", "as", " ", 
              StyleBox["a",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], " ", "SNAP", 
              " ", \(\(structure\)\(.\)\)}]},
          {
            StyleBox["PolynomialReduce",
              FontFamily->"Courier"], 
            RowBox[{"computes", " ", 
              StyleBox["a",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], " ", "reduced", " ", "polynomial", " ", 
              "as", " ", 
              StyleBox["a",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], " ", "SNAP", 
              " ", \(\(structure\)\(.\)\(\ \)\)}]},
          {
            StyleBox["D",
              FontFamily->"Courier",
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontTracking->"Plain",
              FontVariations->{"Underline"->False,
              "Outline"->False,
              "Shadow"->False,
              "StrikeThrough"->False,
              "Masked"->False,
              "CompatibilityType"->0,
              
              "RotationAngle"->
                0}], \(computes\ derivatives\ as\ SNAP\ \(\(structures\)\(.\)\
\)\)}
          }], TraditionalForm]], "DisplayFormula",
  GridBoxOptions->{RowLines->{2, 0.5},
  ColumnLines->True},
  CellTags->"Groups:classical groups"]], "DefinitionBox"],

Cell[TextData[{
  StyleBox["Table ", "SB"],
  StyleBox[
  CounterBox["NumberedTable"], "SB"],
  StyleBox[". ", "SB"],
  "Other Basic Functions"
}], "SmallTextSans",
  CellMargins->{{27, Inherited}, {Inherited, Inherited}}],

Cell[CellGroupData[{

Cell["Examples", "Section"],

Cell["\<\
We show some examples of the package, about basic operations. This \
remains the polynomial used in the above.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(g\)], "Input",
  CellLabel->"In[16]:="],

Cell[BoxData[
    \(\(\(0.37725`\)\(\[InvisibleSpace]\)\) + 2.762`\ x + 7.647`\ x\^2 + 
      9.765`\ x\^3 + 5.503`\ x\^4 + x\^5\)], "Output",
  CellLabel->"Out[16]="]
}, Open  ]],

Cell["\<\
This gives all the roots of the given representative polynomial \
with considerations of the error bound. We recommend you to compare the \
following two results. NSolve with a SNAP structure considers all the \
possible polynomials within the structure, hence their tolerances are larger \
than that of NSolve without a SNAP structure.\
\>", "Text"],

Cell["These evaluations give results with error considerations.", "Commentary"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NSolve[g == 0, x]\)], "Input",
  CellLabel->"In[17]:="],

Cell[BoxData[
    \({{x \[Rule] \(-3.0000720811323233693630293112`12.451896560482764\)}, {x \
\[Rule] \(-0.9989903848991318032656328004`10.488878323990713\)}, {x \[Rule] \
\(-0.5412151824480374484`7.939548909383962\)}, {x \[Rule] \
\(-0.4813611757602536895`8.0343760464362\) - 
            0.0294645370012453413`6.821204608239104\ \[ImaginaryI]}, {x \
\[Rule] \(-0.4813611757602536895`8.0343760464362\) + 
            0.0294645370012453413`6.821204608239104\ \[ImaginaryI]}}\)], \
"Output",
  CellLabel->"Out[17]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Tolerance /@ \((x /. %)\)\)], "Input",
  CellLabel->"In[18]:="],

Cell[BoxData[
    \({1.05982736502957936665826858`14.514107086853524*^-12, 
      3.241029501726395456118204006`14.505377420246694*^-11, 
      6.22043937501758725179356157442`14.67823309883378*^-9, 
      6.28941150360925010069892807736`14.678486617701141*^-9, 
      6.28941150360925010069892807736`14.678486617701141*^-9}\)], "Output",
  CellLabel->"Out[18]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(NSolve[Normal[g] == 0, x]\)], "Input",
  CellLabel->"In[19]:="],

Cell[BoxData[
    \({{x \[Rule] \(-3.0000720811323233693630293112`12.406486330673758\)}, {x \
\[Rule] \(-0.9989903848991318032656328004`10.443468094181657\)}, {x \[Rule] \
\(-0.5412151824480374484`7.894138679574308\)}, {x \[Rule] \
\(-0.4813611757602536895`7.988965816626636\) - 
            0.0294645370012453413`6.775794378429541\ \[ImaginaryI]}, {x \
\[Rule] \(-0.4813611757602536895`7.988965816626636\) + 
            0.0294645370012453413`6.775794378429541\ \[ImaginaryI]}}\)], \
"Output",
  CellLabel->"Out[19]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Tolerance /@ \((x /. %)\)\)], "Input",
  CellLabel->"In[20]:="],

Cell[BoxData[
    \({1.17664474278366996555289856`14.312353501933648*^-12, 
      3.598265576306532285814514775`14.552671874229734*^-11, 
      6.90607501743990298553806793993`14.680643012185827*^-9, 
      6.98264946265843353310967186449`14.680897942161621*^-9, 
      6.98264946265843353310967186449`14.680897942161621*^-9}\)], "Output",
  CellLabel->"Out[20]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(NSolve[
      0.37725`16\[InvisibleSpace] + 2.762`16\ x + 7.647`16\ x\^2 + 
          9.765`16\ x\^3 + 5.503`16\ x\^4 + 1.`16  x\^5 \[Equal] 0, 
      x]\)], "Input",
  CellLabel->"In[21]:="],

Cell[BoxData[
    \({{x \[Rule] \(-3.0000720811323233693630293112`12.445188837095142\)}, {x \
\[Rule] \(-0.9989903848991318032656328004`10.488144866492453\)}, {x \[Rule] \
\(-0.5412151824480374484`7.939505857375257\)}, {x \[Rule] \
\(-0.4813611757602536895`8.03434587464204\) - 
            0.0294645370012453413`6.821174436444947\ \[ImaginaryI]}, {x \
\[Rule] \(-0.4813611757602536895`8.03434587464204\) + 
            0.0294645370012453413`6.821174436444947\ \[ImaginaryI]}}\)], \
"Output",
  CellLabel->"Out[21]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Tolerance /@ \((x /. %)\)\)], "Input",
  CellLabel->"In[22]:="],

Cell[BoxData[
    \({1.07632357367441199463730259`14.514350427202238*^-12, 
      3.246507733545744873875241618`14.50614124651739*^-11, 
      6.22105604341996951147452969159`14.678235377275305*^-9, 
      6.28984846384943642689983899398`14.678488215414191*^-9, 
      6.28984846384943642689983899398`14.678488215414191*^-9}\)], "Output",
  CellLabel->"Out[22]="]
}, Open  ]],

Cell["This gives a result without error considerations.", "Commentary"],

Cell[CellGroupData[{

Cell[BoxData[
    \(System`NSolve[Normal[g] \[Equal] 0, x]\)], "Input",
  CellLabel->"In[23]:="],

Cell[BoxData[
    \({{x \[Rule] \(-3.0000720811323225`\)}, {x \[Rule] \(-0.998990384899134`\
\)}, {x \[Rule] \(-0.5412151824480371`\)}, {x \[Rule] \(-0.48136117576025317`\
\) - 0.02946453700124859`\ \[ImaginaryI]}, {x \[Rule] \(-0.48136117576025317`\
\) + 0.02946453700124859`\ \[ImaginaryI]}}\)], "Output",
  CellLabel->"Out[23]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Tolerance /@ \((x /. %)\)\)], "Input",
  CellLabel->"In[24]:="],

Cell[BoxData[
    \({3.33074910000823053836814551428295`14.402674445050097*^-16, 
      1.10910212669416721696134260152239`14.389476498229513*^-16, 
      6.008695568305212868623124098097`14.229966603804716*^-17, 
      5.3541849581150122348540987955976`14.178540852175638*^-17, 
      5.3541849581150122348540987955976`14.178540852175638*^-17}\)], "Output",\

  CellLabel->"Out[24]="]
}, Open  ]],

Cell["\<\
To show division examples, we prepare the following two \
polynomials.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(g2 = Expand[g*g]\)], "Input",
  CellLabel->"In[25]:="],

Cell[BoxData[
    \(\(\(0.1423175625`\)\(\[InvisibleSpace]\)\) + 2.083929`\ x + 
      13.3983055`\ x\^2 + 49.6097205`\ x\^3 + 116.5704825`\ x\^4 + 
      180.498982`\ x\^5 + 185.042107`\ x\^6 + 122.76759`\ x\^7 + 
      49.813009`\ x\^8 + 11.006`\ x\^9 + x\^10\)], "Output",
  CellLabel->"Out[25]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(h = 1.`16  x^3 + SetPrecision[Random[], 16]\)], "Input",
  CellLabel->"In[26]:="],

Cell[BoxData[
    \(0.4427195513295876794224170681`16.  + 1.`16. \ x\^3\)], "Output",
  CellLabel->"Out[26]="]
}, Open  ]],

Cell[TextData[{
  "This gives the quotient and remainder of ",
  Cell[BoxData[
      \(TraditionalForm\`g2\)]],
  " by ",
  Cell[BoxData[
      \(TraditionalForm\`h\)]],
  " with error considerations. Note that though ",
  Cell[BoxData[
      \(TraditionalForm\`h\)]],
  " is not in SNAP structure, it automatically is transformed into SNAP \
structure."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({{PolynomialQuotient[g2, h, x]}, 
      PolynomialRemainder[g2, h, x]}\)], "Input",
  CellLabel->"In[27]:="],

Cell[BoxData[
    \({{\(-30.1548554720906`\) + 62.41487073851469`\ x + 
          158.4457890051433`\ x\^2 + 180.16953561806653`\ x\^3 + 
          122.32487044867041`\ x\^4 + 49.813009`\ x\^5 + 11.006`\ x\^6 + 
          x\^7}, \(\(13.492461647512513`\)\(\[InvisibleSpace]\)\) - 
        25.548354569649437`\ x - 56.74874311841956`\ x\^2}\)], "Output",
  CellLabel->"Out[27]="]
}, Open  ]],

Cell["\<\
The above commands and the following are the same for univariate \
polynomials.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(PolynomialReduce[g2, {h}, {x}]\)], "Input",
  CellLabel->"In[28]:="],

Cell[BoxData[
    \({{\(-30.1548554720906`\) + 62.41487073851469`\ x + 
          158.4457890051433`\ x\^2 + 180.16953561806653`\ x\^3 + 
          122.32487044867041`\ x\^4 + 49.813009`\ x\^5 + 11.006`\ x\^6 + 
          x\^7}, \(\(13.492461647512513`\)\(\[InvisibleSpace]\)\) - 
        25.548354569649437`\ x - 56.74874311841956`\ x\^2}\)], "Output",
  CellLabel->"Out[28]="]
}, Open  ]],

Cell[TextData[{
  "In this case, ",
  StyleBox["PolynomialRemainder",
    FontFamily->"Courier"],
  " gives a pseudo zero number since ",
  Cell[BoxData[
      \(TraditionalForm\`g\)]],
  " can divide ",
  Cell[BoxData[
      \(TraditionalForm\`g2\)]],
  ". However, these polynomials have their error bounds and we can not argue \
that its remainder is completely zero, hence the following warning messages \
are generated."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({g3, g4} = {PolynomialQuotient[g2, g, x], 
        PolynomialRemainder[g2, g, x]}\)], "Input",
  CellLabel->"In[29]:="],

Cell[BoxData[
    \(SNAP::"invalid" \(\(:\)\(\ \)\) 
      "Tolerance is larger than the representing leading coefficient: \!\(0.`\
\) \[LessEqual] \!\(9.294480043841616`*^-7\)."\)], "Message",
  CellLabel->"\\:6B21\\:3088\\:308A\\:FF1AIn[29]:="],

Cell[BoxData[
    \(SNAP::"invalid" \(\(:\)\(\ \)\) 
      "Tolerance is larger than the representing leading coefficient: \!\(0.`\
\) \[LessEqual] \!\(9.294480043841616`*^-7\)."\)], "Message",
  CellLabel->"\\:6B21\\:3088\\:308A\\:FF1AIn[29]:="],

Cell[BoxData[
    \(SNAP::"invalid" \(\(:\)\(\ \)\) 
      "Tolerance is larger than the representing leading coefficient: \!\(0.`\
\) \[LessEqual] \!\(9.294480043841616`*^-7\)."\)], "Message",
  CellLabel->"\\:6B21\\:3088\\:308A\\:FF1AIn[29]:="],

Cell[BoxData[
    RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(SNAP :: \\\"invalid\\\"\\) will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::stop\\\"]\\)\"\>"}]], \
"Message",
  CellLabel->"\\:6B21\\:3088\\:308A\\:FF1AIn[29]:="],

Cell[BoxData[
    \({\(\(0.37725`\)\(\[InvisibleSpace]\)\) + 2.762`\ x + 7.647`\ x\^2 + 
        9.765`\ x\^3 + 5.503`\ x\^4 + x\^5, 0``6.031774900717962}\)], "Output",\

  CellLabel->"Out[29]="]
}, Open  ]],

Cell[TextData[{
  "SNAP functions give normal ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " numbers if their degrees are not larger than zero."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({SNAPQ[g3], SNAPQ[g4]}\)], "Input",
  CellLabel->"In[30]:="],

Cell[BoxData[
    \({True, False}\)], "Output",
  CellLabel->"Out[30]="]
}, Open  ]],

Cell["\<\
Each operation or calculation enlarge error bounds, hence \
tolerances of the roots also are getting larger and larger as below.\
\>", \
"Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NSolve[g3 \[Equal] 0, x]\)], "Input",
  CellLabel->"In[31]:="],

Cell[BoxData[
    \({{x \[Rule] \(-3.0000720811323233694`6.274928120702081\)}, {x \[Rule] \
\(-0.9989903848991318033`5.478396376726195\)}, {x \[Rule] \
\(-0.5412151824480374484`3.9703737560704813\)}, {x \[Rule] \
\(-0.4813611757602536895`4.127596166473172\) - 
            0.0294645370012453413`2.914424728276078\ \[ImaginaryI]}, {x \
\[Rule] \(-0.4813611757602536895`4.127596166473172\) + 
            0.0294645370012453413`2.914424728276078\ \[ImaginaryI]}}\)], \
"Output",
  CellLabel->"Out[31]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Tolerance /@ \((x /. %)\)\)], "Input",
  CellLabel->"In[32]:="],

Cell[BoxData[
    \({1.5929552247799109756956468754764`14.677142952335963*^-6, 
      3.32020524664598606587715264881257`14.853685854596664*^-6, 
      0.0000579423646668668774993838`14.965315229534575, 
      0.0000507446066785433115621863`14.959450339410328, 
      0.0000507446066785433115621863`14.959450339410328}\)], "Output",
  CellLabel->"Out[32]="]
}, Open  ]],

Cell["\<\
The tolerance correction mechanism used in NSolve with SNAP \
structures suppose that the given representative polynomial does not have \
multiple roots. Therefore, the following warning message  is generated if the \
given polynomial has multiple (or close) roots and any tolerance correction \
is not applied.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NSolve[g2 \[Equal] 0, x]\)], "Input",
  CellLabel->"In[33]:="],

Cell[BoxData[
    \(SNAP::"multipleroots" \(\(:\)\(\ \)\) 
      "The given representative polynomial has multiple roots. Tolerances of \
the roots can not be computed."\)], "Message",
  CellLabel->"\\:6B21\\:3088\\:308A\\:FF1AIn[33]:="],

Cell[BoxData[
    \({{x \[Rule] \(-3.0000720811323283887`6.79793659095208\)}, {x \[Rule] \
\(-3.00007208113231835`6.797936590952076\)}, {x \[Rule] \
\(-0.9989903858280728634`5.786817010304116\)}, {x \[Rule] \
\(-0.9989903839701907336`5.786817007244727\)}, {x \[Rule] \
\(-0.5412152279236396235`2.157949138401507\)}, {x \[Rule] \
\(-0.5412151369723347837`2.157947442349799\)}, {x \[Rule] \
\(-0.4813611980373619149`2.46489286118313\) - 
            0.0294644986528884862`1.2517208376486502\ \[ImaginaryI]}, {x \
\[Rule] \(-0.4813611980373619149`2.46489286118313\) + 
            0.0294644986528884862`1.2517208376486502\ \[ImaginaryI]}, {x \
\[Rule] \(-0.4813611534831957137`2.4648951462689612\) - 
            0.0294645753495020859`1.2517242934069985\ \[ImaginaryI]}, {x \
\[Rule] \(-0.4813611534831957137`2.4648951462689612\) + 
            0.0294645753495020859`1.2517242934069985\ \[ImaginaryI]}}\)], \
"Output",
  CellLabel->"Out[33]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Tolerance /@ \((x /. %)\)\)], "Input",
  CellLabel->"In[34]:="],

Cell[BoxData[
    \({4.7774384270431897481761206923374`14.791601695924102*^-7, 
      4.7774384270432190592856730224112`14.791601695924102*^-7, 
      1.63209073100974389542433597311578`14.688473973102907*^-6, 
      1.63209073947171905138796751658259`14.688473975523593*^-6, 
      0.0037620180005753401718769887`15.207737718780693, 
      0.0037620320602154510867671968`15.207738009507398, 
      0.002333958964430891250346219`15.145963685428221, 
      0.002333958964430891250346219`15.145963685428221, 
      0.0023339464680669715227015905`15.145960976446649, 
      0.0023339464680669715227015905`15.145960976446649}\)], "Output",
  CellLabel->"Out[34]="]
}, Open  ]],

Cell["\<\
Partial derivatives also can be computed in SNAP structures. \
\>", \
"Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(g2d = D[g2, x]\)], "Input",
  CellLabel->"In[35]:="],

Cell[BoxData[
    \(\(\(2.083929`\)\(\[InvisibleSpace]\)\) + 26.796611`\ x + 
      148.8291615`\ x\^2 + 466.28193`\ x\^3 + 902.49491`\ x\^4 + 
      1110.252642`\ x\^5 + 859.37313`\ x\^6 + 398.504072`\ x\^7 + 
      99.054`\ x\^8 + 10.`\ x\^9\)], "Output",
  CellLabel->"Out[35]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(NSolve[g2d == 0, x]\)], "Input",
  CellLabel->"In[36]:="],

Cell[BoxData[
    \({{x \[Rule] \(-3.0000720811323233694`8.566923065286524\)}, {x \[Rule] \
\(-2.5308272775510289792`8.067034632210817\)}, {x \[Rule] \
\(-0.998990384899131803`4.972067184450808\)}, {x \[Rule] \
\(-0.8692254815392273313`4.262890222476106\)}, {x \[Rule] \
\(-0.5412151824480368253`0.07574789952197347\)}, {x \[Rule] 
          0``-1.1084579531959013}, {x \[Rule] 
          0``-1.007229585454007}, {x \[Rule] \
\(-0.4813611757602539841`0.25338339684598155\) + 
            0``0.5709123375647115\ \[ImaginaryI]}, {x \[Rule] \
\(-0.4813611757602539841`0.25338339684598155\) + 
            0``0.5709123375647115\ \[ImaginaryI]}}\)], "Output",
  CellLabel->"Out[36]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Tolerance /@ \((x /. %)\)\)], "Input",
  CellLabel->"In[37]:="],

Cell[BoxData[
    \({8.13221073251823824168964816176`14.684436759566854*^-9, 
      2.168841798426865843990389763824`14.707931498534261*^-8, 
      0.00001065354448819472915331578328329049`14.700532201197124, 
      0.00004745065664697163286823715426170962`14.956512725698872, 
      0.4545922961971204403040339907`16.057868321675425, 
      12.8368348291395277253281678009`15.353229365177462, 
      10.1678606464998043420709920769`15.589245607629707, 
      0.3798417168646954000446470258`15.9687141223348, 
      0.3798417168646954000446470258`15.9687141223348}\)], "Output",
  CellLabel->"Out[37]="]
}, Open  ]],

Cell[TextData[{
  "In this case, the working precision used in ",
  StyleBox["System`NSolve",
    FontFamily->"Courier"],
  " is too small, so enlarge the precision gives us better answers."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NSolve[g2d == 0, x, 32]\)], "Input",
  CellLabel->"In[38]:="],

Cell[BoxData[
    \({{x \[Rule] \(-3.0000720811323233693632654706`10.367077689985788\)}, {x \
\[Rule] \(-2.5308272775510289791613863995`10.240070815092158\)}, {x \[Rule] \
\(-0.9989903848991318032`9.15563424433536\)}, {x \[Rule] \
\(-0.8692254815392273303`8.73834527426704\)}, {x \[Rule] \
\(-0.5412151824480374499`6.166918145377783\)}, {x \[Rule] \
\(-0.5094234012658212724`5.3552452881656185\)}, {x \[Rule] \
\(-0.4929238396439224181`5.358826089716271\)}, {x \[Rule] \
\(-0.4813611757602536887`6.339715519679965\) - 
            0.0294645370012453425`5.126544081482871\ \[ImaginaryI]}, {x \
\[Rule] \(-0.4813611757602536887`6.339715519679965\) + 
            0.0294645370012453425`5.126544081482871\ \[ImaginaryI]}}\)], \
"Output",
  CellLabel->"Out[38]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Tolerance /@ \((x /. %)\)\)], "Input",
  CellLabel->"In[39]:="],

Cell[BoxData[
    \({1.2884097403623410349588855385`14.597180161149632*^-10, 
      1.4561016419520578381129804383`14.599519873192252*^-10, 
      6.9811515168095660958672235194`14.594776021815075*^-10, 
      1.58776847570078961200425305299`14.534607072533955*^-9, 
      3.6851216227806676582872463395653`14.783923524199723*^-7, 
      2.24819306083059217069208067597535`14.83812846653758*^-6, 
      2.15751454916419144534622915934287`14.81887596279349*^-6, 
      3.1136553394309446631706035272608`14.779011331520701*^-7, 
      3.1136553394309446631706035272608`14.779011331520701*^-7}\)], "Output",
  CellLabel->"Out[39]="]
}, Open  ]],

Cell[TextData[{
  "One may think that this package is useless. The followings may be counter \
examples to them. The leading coefficients of ",
  Cell[BoxData[
      \(TraditionalForm\`newg\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`newg2\)]],
  " have low accuracy numbers. Hence, the precisions and accuracirs of \
coefficients on lower degree terms become lower. "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(newg = 
      1.001`6  x^5 + \((5503  x^4 + 9765  x^3 + 7647  x^2 + 2762  x + 377)\)/
          1000\)], "Input",
  CellLabel->"In[40]:="],

Cell[BoxData[
    \(1.001`5.999999999999999\ x\^5 + \(377 + 2762\ x + 7647\ x\^2 + 9765\ \
x\^3 + 5503\ x\^4\)\/1000\)], "Output",
  CellLabel->"Out[40]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(newg2 = Expand[newg^2]\)], "Input",
  CellLabel->"In[41]:="],

Cell[BoxData[
    \(142129\/1000000 + \(520637\ x\)\/250000 + \(6697241\ x\^2\)\/500000 + \
\(24802419\ x\^3\)\/500000 + \(116567731\ x\^4\)\/1000000 + 
      180.499236`8.378669944656089\ x\^5 + 
      185.047631`7.524595782195373\ x\^6 + 
      122.7828839999999990687`6.904182666808125\ x\^7 + 
      49.8325390000000000002`6.406376694551547\ x\^8 + 
      11.0170060000000000003`5.999999999999999\ x\^9 + 
      1.0020010000000000001`5.698970004336017\ x\^10\)], "Output",
  CellLabel->"Out[41]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(qofnewg2 = System`PolynomialQuotient[newg2, newg, x]\)], "Input",
  CellLabel->"In[42]:="],

Cell[BoxData[
    \(0.3770000000004689179`0.6532872578215781 + 
      2.7619999999996594761`2.36601592227288\ x + 
      7.6470000000000735015`3.6561271484490563\ x\^2 + 
      9.7650000000000000001`4.609268262721972\ x\^3 + 
      5.5029999999999999999`5.221848749616356\ x\^4 + 
      1.0010000000000000001`5.522878745280337\ x\^5\)], "Output",
  CellLabel->"Out[42]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Map[Tolerance, CoefficientList[qofnewg2, x]]\)], "Input",
  CellLabel->"In[43]:="],

Cell[BoxData[
    \({0.0837633604837701654547362713`15.351823247397052, 
      0.0118907090319978911631314865`15.12037590016638, 
      0.0016879669606956531923164417`14.982612047692037, 
      0.0002401065374625391168956593`14.888473820203483, 
      0.00003301800000000009544469527147762021`14.802670564671018, 
      3.00300000000001134195079329688822`14.850242708344911*^-6}\)], "Output",\

  CellLabel->"Out[43]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Mathematical Background", "Section",
  ShowCellBracket->True],

Cell[CellGroupData[{

Cell["Polynomial Division (univariate case)", "Subsection"],

Cell[TextData[{
  "Let ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`g(x)\)]],
  " be the following polynomials of degrees ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(\[LessEqual]\)\(n\))\)\)]],
  " with tolerances ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\_f\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\_g\)]],
  ", respectively."
}], "Text"],

Cell[BoxData[
    \(TextForm\`f \((x)\) = \(f\_n\) x\^n + \(f\_\(n - 1\)\) 
          x\^\(n - 1\) + \[CenterEllipsis] + \(f\_1\) x + f\_0, \ 
    f\_i \[Element] \[DoubleStruckCapitalC], \[IndentingNewLine]g \((x)\) = \
\(g\_m\) x\^m + \(g\_\(m - 1\)\) x\^\(m - 1\) + \[CenterEllipsis] + \(g\_1\) 
          x + g\_0, \ 
    g\_i \[Element] \(\(\[DoubleStruckCapitalC]\)\(.\)\)\)], \
"NumberedEquation",
  CellMargins->{{103, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "Dividing ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\)]],
  " by ",
  Cell[BoxData[
      \(TraditionalForm\`g(x)\)]],
  " is defined as follows, with polynomials ",
  Cell[BoxData[
      \(TraditionalForm\`q(x)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`r(x)\)]],
  "."
}], "Text"],

Cell[BoxData[
    \(TextForm\`f \((x)\) = q \((x)\)\ g \((x)\) + r \((x)\), \ 
    deg\ q = n - m, \ deg\ r < \(\(m\)\(.\)\)\)], "NumberedEquation",
  CellMargins->{{103, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "For SNAP structures, we have to take care of the following polynomials ",
  Cell[BoxData[
      \(TraditionalForm\`\(q\&_\)(x)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(r\&_\)(x)\)]],
  " for the given ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\&_\)(x)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(g\&_\)(x)\)]],
  "."
}], "Text"],

Cell[BoxData[
    \(TextForm\`\(f\&_\) \((x)\) = \(q\&_\) \((x)\)\ \(g\&_\) \((x)\) + \
\(r\&_\) \((x)\), \ deg\ q\&_ = n - m, \ deg\ r\&_ < m, \ 
    f\&_ \[Element] \(P\_*\) \((f, \[Epsilon]\_f)\), \ 
    g\&_ \[Element] \(P\_*\) \(\((g, \[Epsilon]\_g)\)\(.\)\)\)], \
"NumberedEquation",
  CellMargins->{{103, Inherited}, {Inherited, Inherited}}],

Cell["\<\
We have the following corollaries [Nag04b]. Note that the \
discussion at the end of the subsection \[OpenCurlyDoubleQuote]Tolerance \
Mechanisms\[CloseCurlyDoubleQuote].\
\>", "Text"],

Cell["Corollary 2 (Corollary 2 in [Nag04b])", "Text",
  FontWeight->"Bold"],

Cell["If the following expression holds,", "Text",
  CellMargins->{{87, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(TextForm\`\(\[Sigma]\_2\) \(\@\(n + 1\)\) \[Epsilon]\_g < 
      1, \ \[Sigma]\_2 = \(\(\[DoubleVerticalBar]\)\(G\^\(-1\)\)\( \
\[DoubleVerticalBar] \_2\)\), \)], "NumberedEquation",
  CellMargins->{{103, Inherited}, {Inherited, Inherited}}],

Cell["we have", "Text",
  CellMargins->{{87, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(TextForm\`\[ForAll] f\&_ \[Element] \(P\_2\) \((f, \[Epsilon]\_f)\), \ \
\[ForAll] g\&_ \[Element] \(P\_2\) \((g, \[Epsilon]\_g)\), \ 
    q\&_ \[Element] \(P\_2\) \((q, \[Epsilon]\_q)\), \ 
    r\&_ \[Element] \(P\_2\) \((r, \[Epsilon]\_r)\), \[IndentingNewLine]\
\[Epsilon]\_q = \(\[Sigma]\_2\) \((\[Epsilon]\_f + \(\@\(n + 
                    1\)\) \(\[Epsilon]\_g\) \
\((\(\[DoubleVerticalBar]\)\(q\)\( \[DoubleVerticalBar] \_2\)\(\(+\[Sigma]\_2\
\) \[Epsilon]\_f\))\)/\((1 - \(\[Sigma]\_2\) \(\@\(n + 
                            1\)\) \[Epsilon]\_g)\))\), \[IndentingNewLine]\
\[Epsilon]\_r = \[Epsilon]\_f + \(\@\(\[LeftCeiling]n\/2\[RightCeiling] + 
                1\)\) \(\((\(\[DoubleVerticalBar]\)\(g\)\( \
\[DoubleVerticalBar] \
\_2\)\(\(\[Epsilon]\_q\)\(+\)\)\(\[DoubleVerticalBar]\)\(q\)\( \
\[DoubleVerticalBar] \_2\)\(\[Epsilon]\_g + \(\[Epsilon]\_g\) \
\[Epsilon]\_q\))\)\(.\)\)\)], "NumberedEquation",
  CellMargins->{{103, Inherited}, {Inherited, Inherited}}],

Cell["Corollary 3 (Corollary 3 in [Nag04b])", "Text",
  FontWeight->"Bold"],

Cell["If the following expression holds,", "Text",
  CellMargins->{{87, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(TextForm\`\[Sigma]\_1\ \[Epsilon]\_g < 
      1, \ \[Sigma]\_1 = \(\(\[DoubleVerticalBar]\)\(G\^\(-1\)\)\( \
\[DoubleVerticalBar] \_1\)\), \)], "NumberedEquation",
  CellMargins->{{103, Inherited}, {Inherited, Inherited}}],

Cell["we have", "Text",
  CellMargins->{{87, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(TextForm\`\[ForAll] f\&_ \[Element] \(P\_1\) \((f, \[Epsilon]\_f)\), \ \
\[ForAll] g\&_ \[Element] \(P\_1\) \((g, \[Epsilon]\_g)\), \ 
    q\&_ \[Element] \(P\_1\) \((q, \[Epsilon]\_q)\), \ 
    r\&_ \[Element] \(P\_1\) \((r, \[Epsilon]\_r)\), \[IndentingNewLine]\
\[Epsilon]\_q = \(\[Sigma]\_1\) \((\[Epsilon]\_f + \(\[Epsilon]\_g\) \((\(\
\[DoubleVerticalBar]\)\(q\)\( \[DoubleVerticalBar] \_1\)\(\(+\[Sigma]\_1\) \
\[Epsilon]\_f\))\)/\((1 - \[Sigma]\_1\ \[Epsilon]\_g)\))\), \
\[IndentingNewLine]\[Epsilon]\_r = \(\(\[Epsilon]\_f\)\(+\)\) \
\[DoubleVerticalBar] 
        g\( \[DoubleVerticalBar] \_1\)\(\(\[Epsilon]\_q\)\(+\)\) \
\[DoubleVerticalBar] 
        q\( \[DoubleVerticalBar] \_1\)\[Epsilon]\_g + \(\[Epsilon]\_g\) \(\(\
\[Epsilon]\_q\)\(.\)\)\)], "NumberedEquation",
  CellMargins->{{103, Inherited}, {Inherited, Inherited}}],

Cell["Corollary 4 (Corollary 4 in [Nag04b])", "Text",
  FontWeight->"Bold"],

Cell["If the following expression holds,", "Text",
  CellMargins->{{87, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(TextForm\`\(\[Sigma]\_\[Infinity]\) \((n + 1)\) \[Epsilon]\_g < 
      1, \ \[Sigma]\_\[Infinity] = \(\(\[DoubleVerticalBar]\)\(G\^\(-1\)\)\( \
\[DoubleVerticalBar] \_\[Infinity]\)\), \)], "NumberedEquation",
  CellMargins->{{103, Inherited}, {Inherited, Inherited}}],

Cell["we have", "Text",
  CellMargins->{{87, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(TextForm\`\[ForAll] f\&_ \[Element] \(P\_\[Infinity]\) \((f, \[Epsilon]\
\_f)\), \ \[ForAll] g\&_ \[Element] \(P\_\[Infinity]\) \((g, \
\[Epsilon]\_g)\), \ 
    q\&_ \[Element] \(P\_\[Infinity]\) \((q, \[Epsilon]\_q)\), \ 
    r\&_ \[Element] \(P\_\[Infinity]\) \((r, \[Epsilon]\_r)\), \
\[IndentingNewLine]\[Epsilon]\_q = \(\[Sigma]\_\[Infinity]\) \((\[Epsilon]\_f \
+ \((n + 1)\) \(\[Epsilon]\_g\) \((\(\[DoubleVerticalBar]\)\(q\)\( \
\[DoubleVerticalBar] \_\[Infinity]\)\(\(+\[Sigma]\_\[Infinity]\) \
\[Epsilon]\_f\))\)/\((1 - \(\[Sigma]\_\[Infinity]\) \((n + 
                          1)\) \[Epsilon]\_g)\))\), \[IndentingNewLine]\
\[Epsilon]\_r = \[Epsilon]\_f + \((\[LeftCeiling]n\/2\[RightCeiling] + 
              1)\) \(\((\(\[DoubleVerticalBar]\)\(g\)\( \[DoubleVerticalBar] \
\_\[Infinity]\)\(\(\[Epsilon]\_q\)\(+\)\)\(\[DoubleVerticalBar]\)\(q\)\( \
\[DoubleVerticalBar] \_\[Infinity]\)\(\[Epsilon]\_g + \(\[Epsilon]\_g\) \
\[Epsilon]\_q\))\)\(.\)\)\)], "NumberedEquation",
  CellMargins->{{103, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "In the above corollaries, ",
  Cell[BoxData[
      \(TraditionalForm\`A\^\(-1\)\)]],
  " denotes the inverse matrix of ",
  Cell[BoxData[
      \(TraditionalForm\`A\)]],
  " and G is the following matrix of size ",
  Cell[BoxData[
      \(TraditionalForm\`\((n + 1)\)\[Times]\((n + 1)\)\)]],
  "."
}], "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{"G", "=", 
        RowBox[{
          RowBox[{"(", GridBox[{
                {\(g\_m\), "0", "\[CenterEllipsis]", "\[CenterEllipsis]", "0",
                   "0"},
                {\(g\_\(m - 1\)\), \(g\_m\), "\[DescendingEllipsis]", 
                  "\[DescendingEllipsis]", "\[VerticalEllipsis]", 
                  "\[VerticalEllipsis]"},
                {"\[VerticalEllipsis]", \(g\_\(m - 1\)\), 
                  "\[DescendingEllipsis]", "\[DescendingEllipsis]", 
                  "\[VerticalEllipsis]", "\[VerticalEllipsis]"},
                {\(g\_0\), "\[VerticalEllipsis]", "\[DescendingEllipsis]", 
                  "\[DescendingEllipsis]", "0", "\[VerticalEllipsis]"},
                {"\[VerticalEllipsis]", "\[VerticalEllipsis]", 
                  "\[DescendingEllipsis]", "\[DescendingEllipsis]", \(g\_m\), 
                  "0"},
                {"0", "\[CenterEllipsis]", "\[CenterEllipsis]", 
                  "\[CenterEllipsis]", \(g\_\(m - 1\)\), \(g\_m\)}
                }], ")"}], "."}]}], TextForm]], "NumberedEquation",
  CellMargins->{{103, Inherited}, {Inherited, Inherited}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Polynomial Reduction (more than one variable case)", "Subsection"],

Cell["\<\
In this version, the SNAP structure is extended to multivariate \
polynomials, hence we introduce polynomial reductions for that. However, a \
reduction can be done by two multiplications and one subtraction. There is \
nothing to do except for operations for normal polynomial reductions. We just \
reduce polynomials by ordinary algorithms, but using SNAP structures \
introduced in the previous section.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Root Finding (with error considerations)", "Subsection"],

Cell[TextData[{
  "There are a lot of root finding methods. For example, basically, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " uses Jenkins\[Hyphen]Traub method. Since those roots found by numerical \
methods may not the exact ones, we have to consider numerical errors after \
calculations. For example, Smith [Smi70] studied error bounds for numerical \
roots."
}], "Text"],

Cell["\<\
However, operating polynomials with errors on their coefficients \
extends the problem. In Terui and Sasaki [TS00], they studied an extended \
version of Smith's work, by which we can bound errors included in numerical \
roots of polynomials with errors on their coefficients and for polynomials \
represented as SNAP structures.\
\>", "Text"],

Cell["Lemma 3 (Statement in [TS00])", "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  "For any polynomial ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\&_\)(x) \[Element] \(P\_*\)(f, \[Epsilon])\)]],
  ", we have"
}], "Text",
  CellMargins->{{87, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox["|",
            SpanMaxSize->1], 
          StyleBox[\(\[Zeta]\_i - \[Zeta]\&_\_\(\[Pi] \((i)\)\)\),
            SpanMaxSize->1], 
          StyleBox["|",
            
            SpanMaxSize->
              1], \(\(\[LessEqual]\)\(n\ \(\(|\)\(f \((\[Zeta]\_i)\)\)\(|\)\(\
\(+\ \[Epsilon]\)\ \[Sum]\_\(j = 0\)\%n\)\(|\)\(\[Zeta]\_i\)\( | \
\^j\)\)\/\(\((\(|\)\(f\_n\)\(|\)\(+\ \[Epsilon]\))\) | \[Product]\_\(j = 1, \
\(\(\[NotEqual]\)\(i\)\)\)\%n\((\[Zeta]\_i - \[Zeta]\_j)\) | \)\)\)}], ","}], 
      TextForm]], "NumberedEquation",
  CellMargins->{{103, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " denotes the degree of ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta]\_1, \[Ellipsis], \ \[Zeta]\_n\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta]\&_\_\(\[Pi](1)\), \ \[Ellipsis], \ \
\[Zeta]\&_\_\(\[Pi](n)\)\)]],
  " are the roots of ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\&_\)(x)\)]],
  ", respectively, and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Pi](i)\)]],
  " is a permutation on ",
  Cell[BoxData[
      \(TraditionalForm\`{1, \ \[Ellipsis], \ n}\)]],
  ", which minimizes the maximum distance between the roots: ",
  Cell[BoxData[
      \(TraditionalForm\`max\_i\(\(|\)\(\[Zeta]\_i - \[Zeta]\&_\_\(\[Pi](i)\)\
\)\(|\)\)\)]],
  "."
}], "Text",
  CellMargins->{{87, Inherited}, {Inherited, Inherited}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Partial Derivation (with error considerations)", "Subsection"],

Cell["\<\
Computing the partial derivation of the given polynomial is also \
important. We have the following trivial lemma to calculate the derivations \
of SNAP structures.\
\>", "Text"],

Cell["Lemma 4", "Text",
  FontWeight->"Bold"],

Cell[TextData[{
  "For any polynomial ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\&_\)(u\_1, \ \[Ellipsis], \ 
          u\_r) \[Element] \(P\_*\)(f, \[Epsilon])\)]],
  ", we have"
}], "Text",
  CellMargins->{{87, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(TextForm\`\(\[PartialD]f\&_ \((u\_1, \ \[Ellipsis], \ u\_r)\)\)\/\
\[PartialD]u\_i \[Element] \(P\_*\) \((\(\[PartialD]f \((u\_1, \ \[Ellipsis], \
\ u\_r)\)\)\/\[PartialD]u\_i, \ \[Epsilon]\[Times]\(deg\_\(u\_i\)\) 
            f)\)\ \ \ \ \ \ \ \ \ \ \ \ \ \(\((i = 1, \[Ellipsis], \ 
            r)\)\(.\)\)\)], "NumberedEquation",
  CellMargins->{{103, Inherited}, {Inherited, Inherited}}]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Symbolic Numeric Algorithms Implemented", "Chapter"],

Cell["\<\
Using the above basic features, we have started to modify and \
implement known symbolic numeric algorithms. In the below and the current \
implementations, one algorithm for each computation is only used, however, \
this is not intended and other algorithms will be implemented in the near \
future.\
\>", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {Cell["function"], Cell["purpose"]},
          {
            StyleBox["PolynomialGCD",
              FontFamily->"Courier"], \(computes\ an\ \[Epsilon] - 
              GCD\ of\ the\ given\ two\ \(\(polynomials\)\(.\)\)\)},
          {
            "CoprimeQ", \(gives\ True\ if\ the\ two\ polynomials\ are\ \
coprime\ within\ the\ tolerance\ or\ significant\ \(\(numbers\)\(.\)\)\)},
          {
            StyleBox["ApproximateDivisorQ",
              FontFamily->"Courier"], 
            RowBox[{"gives", " ", 
              StyleBox["True",
                FontFamily->"Courier"], " ", "if", " ", "the", " ", "first", 
              " ", "argument", " ", "is", " ", "divisible", " ", "by", " ", 
              "the", " ", "second", " ", "one", 
              " ", \(\(approximately\)\(.\)\)}]},
          {
            StyleBox["ApproximateQuotient",
              FontFamily->"Courier"], 
            RowBox[{"gives", " ", 
              StyleBox["a",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], " ", "quotient", " ", "if", " ", 
              StyleBox["ApproximateDivisorQ",
                FontFamily->"Courier"], " ", "is", " ", 
              RowBox[{
                StyleBox["True",
                  FontFamily->"Courier"], ".", " "}]}]},
          {
            StyleBox["NearestSingularPolynomial",
              
              FontFamily->
                "Courier"], \(computes\ the\ nearest\ singular\ polynomial\ \
\(\((\ tolerace\ is\ not\ considered)\)\(.\)\)\)},
          {
            StyleBox["AbsolutelyIrreducibleQ",
              FontFamily->"Courier"], 
            RowBox[{"gives", " ", 
              StyleBox["True",
                FontFamily->"Courier"], " ", "if", " ", "the", " ", 
              "polynomial", " ", "is", " ", "absolutely", " ", "irreducible", 
              " ", "within", " ", "the", " ", \(\(tolerance\)\(.\)\)}]},
          {
            StyleBox["SeparationBound",
              FontFamily->"Courier"], 
            RowBox[{"computes", " ", 
              StyleBox["a",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], " ", "separation", " ", "bound", " ", 
              "of", " ", "the", " ", "given", 
              " ", \(\(polynomial\)\(.\)\)}]},
          {
            StyleBox["Factor",
              
              FontFamily->
                "Courier"], \(factorizes\ the\ given\ polynomial\ \
\(\(numerically\)\(.\)\)\)},
          {
            StyleBox["FactorList",
              FontFamily->"Courier"], 
            RowBox[{"gives", " ", 
              StyleBox["a",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False,
                "StrikeThrough"->False,
                "Masked"->False,
                "CompatibilityType"->0,
                "RotationAngle"->0}], " ", "list", " ", "of", " ", "pseudo", 
              " ", "factors", " ", "of", " ", "the", " ", "given", 
              " ", \(\(polynomial\)\(.\)\)}]}
          }], TraditionalForm]], "DisplayFormula",
  GridBoxOptions->{RowLines->{2, 0.5},
  ColumnLines->True},
  CellTags->"Groups:classical groups"]], "DefinitionBox"],

Cell[TextData[{
  StyleBox["Table ", "SB"],
  StyleBox[
  CounterBox["NumberedTable"], "SB"],
  StyleBox[". ", "SB"],
  "Symbolic Numeric Functions"
}], "SmallTextSans",
  CellMargins->{{27, Inherited}, {Inherited, Inherited}}],

Cell[CellGroupData[{

Cell["Examples", "Section"],

Cell["\<\
We show some examples of the package, about SNAP operations. This \
remains the polynomial used in the above.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(g\)], "Input",
  CellLabel->"In[44]:="],

Cell[BoxData[
    \(\(\(0.37725`\)\(\[InvisibleSpace]\)\) + 2.762`\ x + 7.647`\ x\^2 + 
      9.765`\ x\^3 + 5.503`\ x\^4 + x\^5\)], "Output",
  CellLabel->"Out[44]="]
}, Open  ]],

Cell["\<\
Introduce another polynomial. Though we retain it as not in a SNAP \
structure, treating it in that is also acceptable.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(h = 
      1.3883`16\[InvisibleSpace] + 4.417`16\ x + 3.8861`16\ x\^2 + 
        0.85593`16\ x\^3\)], "Input",
  CellLabel->"In[45]:="],

Cell[BoxData[
    \(1.3883`16.000000000000004 + 4.417`16.000000000000004\ x + 
      3.8861`16.000000000000004\ x\^2 + 
      0.85593`16.000000000000004\ x\^3\)], "Output",
  CellLabel->"Out[45]="]
}, Open  ]],

Cell["The built-in function outputs these polynomial are coprime.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(System`PolynomialGCD[Normal[g], h]\)], "Input",
  CellLabel->"In[46]:="],

Cell[BoxData[
    \(1\/4000\)], "Output",
  CellLabel->"Out[46]="]
}, Open  ]],

Cell[TextData[{
  "SNAP package can compute a their ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)]],
  "-GCD as below, where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon] = 0.0001\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(gcdofgh = PolynomialGCD[g, h, 0.0001`16]\)], "Input",
  CellLabel->"In[50]:="],

Cell[BoxData[
    \(SNAP::"preliminary" \(\(:\)\(\ \)\) 
      "Preliminary implemented function is called."\)], "Message",
  CellLabel->"\\:6B21\\:3088\\:308A\\:FF1AIn[50]:="],

Cell[BoxData[
    \(\(\(0.00005`\)\(\[InvisibleSpace]\)\) + 0.00015907944968666715`\ x + 
      0.00013995894259165886`\ x\^2 + 
      0.00003082655045739393`\ x\^3\)], "Output",
  CellLabel->"Out[50]="]
}, Open  ]],

Cell["We can check its approximate divisibility.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ApproximateDivisorQ[g, gcdofgh, 0.0001`16]\)], "Input",
  CellLabel->"In[51]:="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[51]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ApproximateQuotient[g, gcdofgh, 0.0001`16]\)], "Input",
  CellLabel->"In[52]:="],

Cell[BoxData[
    \(\(\(7543.972371664776`\)\(\[InvisibleSpace]\)\) + 
      31237.66598363115`\ x + 32438.96839463335`\ x\^2\)], "Output",
  CellLabel->"Out[52]="]
}, Open  ]],

Cell["\<\
Without any tolerance, the maximum tolerance between the given \
polynomials is used.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(PolynomialGCD[g, h] // Timing\)], "Input",
  CellLabel->"In[53]:="],

Cell[BoxData[
    \(SNAP::"preliminary" \(\(:\)\(\ \)\) 
      "Preliminary implemented function is called."\)], "Message",
  CellLabel->"\\:6B21\\:3088\\:308A\\:FF1AIn[53]:="],

Cell[BoxData[
    \({0.810999999999999`\ Second, 1}\)], "Output",
  CellLabel->"Out[53]="]
}, Open  ]],

Cell["\<\
This also checks whether they are coprime or not within their \
tolerance.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(CoprimeQ[g, h] // Timing\)], "Input",
  CellLabel->"In[54]:="],

Cell[BoxData[
    \({0.07099999999999973`\ Second, True}\)], "Output",
  CellLabel->"Out[54]="]
}, Open  ]],

Cell[TextData[{
  "This gives the nearest singular polynomial of ",
  Cell[BoxData[
      \(TraditionalForm\`g\)]],
  ", so the output polynomial ",
  Cell[BoxData[
      \(TraditionalForm\`nsg\)]],
  " has a double root."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(nsg = NearestSingularPolynomial[g]\)], "Input",
  CellLabel->"In[55]:="],

Cell[BoxData[
    \(SNAP::"preliminary" \(\(:\)\(\ \)\) 
      "Preliminary implemented function is called."\)], "Message",
  CellLabel->"\\:6B21\\:3088\\:308A\\:FF1AIn[55]:="],

Cell[BoxData[
    \(0.3772035197483813701677578908898396818763600422140656721197769713561301\
7214802`62.180990684161266 + 
      2.7620229415240444334283504894063958576218693665264727856231377878387684\
7587565`63.25240765654008\ x + 
      7.6469886766205613576225041617310994650085222144475957978865060135373168\
1741202`63.92016650122782\ x\^2 + 
      9.7650055889452532941127029302322860194239056859654563607269875010535303\
9650504`64.26464678431904\ x\^3 + 
      5.5029972414322761523668220364701836077471614600933081235123015006948311\
0355288`64.26317991397421\ x\^4 + x\^5\)], "Output",
  CellLabel->"Out[55]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(x /. NSolve[nsg == 0, x]\)], "Input",
  CellLabel->"In[56]:="],

Cell[BoxData[
    \(SNAP::"multipleroots" \(\(:\)\(\ \)\) 
      "The given representative polynomial has multiple roots. Tolerances of \
the roots can not be computed."\)], "Message",
  CellLabel->"\\:6B21\\:3088\\:308A\\:FF1AIn[56]:="],

Cell[BoxData[
    \({\(-3.\
00005313065094568375230434318607841057397433984142283781058763766680702446852`\
60.955270094423\), \
\(-0.9993512817134660583032410448644260135642552612868565250016588763365995831\
3288`59.84924557426989\), \
\(-0.5164413724592175098972076648365735469193342793208424522206174451433216109\
8457`57.60641875039687\), \
\(-0.493575728304323450207034491791553778728861567829`29.49018048018935\), \
\(-0.493575728304323450207034491791551926818921518859`29.49018048018935\)}\)],\
 "Output",
  CellLabel->"Out[56]="]
}, Open  ]],

Cell["\<\
To show the example of absolutely irreducibility testing, we define \
the following bivariate polynomial.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(f = 
      Expand[\((x^2 + y*x + 2  y - 1)\) \((x^3 + y^2\ x - y + 7)\) + 
          0.2`16  x]\)], "Input",
  CellLabel->"In[57]:="],

Cell[BoxData[
    \(\(-7\) + 0.2`16. \ x + 7\ x\^2 - x\^3 + x\^5 + 15\ y + 7\ x\ y - 
      x\^2\ y + 2\ x\^3\ y + x\^4\ y - 2\ y\^2 - 2\ x\ y\^2 + x\^3\ y\^2 + 
      2\ x\ y\^3 + x\^2\ y\^3\)], "Output",
  CellLabel->"Out[57]="]
}, Open  ]],

Cell[TextData[{
  "This tests its absolutely irreducibility within the given tolerance ",
  Cell[BoxData[
      \(TraditionalForm\`0.00001\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(AbsolutelyIrreducibleQ[f, 0.00001`16]\)], "Input",
  CellLabel->"In[59]:="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[59]="]
}, Open  ]],

Cell["\<\
If the given polynomial has a SNAP structure, its tolerance is \
used, so the following evaluations give the same result.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(fs = SNAP[f, 0.00001`16]\)], "Input",
  CellLabel->"In[61]:="],

Cell[BoxData[
    \(\(-7.`\) + 0.2`\ x + 7.`\ x\^2 - 1.`\ x\^3 + x\^5 + 15.`\ y + 
      7.`\ x\ y - 1.`\ x\^2\ y + 2.`\ x\^3\ y + x\^4\ y - 2.`\ y\^2 - 
      2.`\ x\ y\^2 + x\^3\ y\^2 + 2.`\ x\ y\^3 + x\^2\ y\^3\)], "Output",
  CellLabel->"Out[61]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(AbsolutelyIrreducibleQ[fs]\)], "Input",
  CellLabel->"In[62]:="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[62]="]
}, Open  ]],

Cell[TextData[{
  "We can compute a separation bound of ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " also. In this case, all the polynomial of ",
  Cell[BoxData[
      \(TraditionalForm\`\(P\_2\)(f, 0.000791621567)\)]],
  " are absolutely irreducible."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SeparationBound[f]\)], "Input",
  CellLabel->"In[63]:="],

Cell[BoxData[
    \(0.0007916215678719798758995567`10.251025827330634\)], "Output",
  CellLabel->"Out[63]="]
}, Open  ]],

Cell[TextData[{
  "This gives an example using the algorithm adapted for the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s coefficient-wise accuracy concept. Hence, changing all the coefficients \
within their accuracy does not change its absolute irreducibility."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(AbsolutelyIrreducibleQ[f]\)], "Input",
  CellLabel->"In[64]:="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[64]="]
}, Open  ]],

Cell["\<\
For numerical polynomials, the built-in function gives the input.\
\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(f2 = 
      N@Expand[\((x^2 + y*x + 2  y - 1)\) \((x^3 + y^2\ x - y + 
                7)\)]\)], "Input",
  CellLabel->"In[65]:="],

Cell[BoxData[
    \(\(-7.`\) + 7.`\ x\^2 - 1.`\ x\^3 + x\^5 + 15.`\ y + 7.`\ x\ y - 
      1.`\ x\^2\ y + 2.`\ x\^3\ y + x\^4\ y - 2.`\ y\^2 - 2.`\ x\ y\^2 + 
      x\^3\ y\^2 + 2.`\ x\ y\^3 + x\^2\ y\^3\)], "Output",
  CellLabel->"Out[65]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(System`Factor[f2]\)], "Input",
  CellLabel->"In[66]:="],

Cell[BoxData[
    \(1.`\ \((\(-7.`\) + 7.`\ x\^2 - 1.`\ x\^3 + 1.`\ x\^5 + 15.`\ y + 
          7.`\ x\ y - 1.`\ x\^2\ y + 2.`\ x\^3\ y + 1.`\ x\^4\ y - 
          2.`\ y\^2 - 2.`\ x\ y\^2 + 1.`\ x\^3\ y\^2 + 2.`\ x\ y\^3 + 
          1.`\ x\^2\ y\^3)\)\)], "Output",
  CellLabel->"Out[66]="]
}, Open  ]],

Cell["\<\
With the SNAP package, for example, we can factorize it numerically \
with a backward error bound.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Chop@Factor[f2, 0.0000001`16]\)], "Input",
  CellLabel->"In[70]:="],

Cell[BoxData[
    \(SNAP::"machineprecision" \(\(:\)\(\ \)\) 
      "SNAP function encounters a machine precision number. Machine precision \
numbers may not have enough accuracy due to Mathematica's inner operation \
policy."\)], "Message",
  CellLabel->"\\:6B21\\:3088\\:308A\\:FF1AIn[70]:="],

Cell[BoxData[
    \(SNAP::"machineprecision" \(\(:\)\(\ \)\) 
      "SNAP function encounters a machine precision number. Machine precision \
numbers may not have enough accuracy due to Mathematica's inner operation \
policy."\)], "Message",
  CellLabel->"\\:6B21\\:3088\\:308A\\:FF1AIn[70]:="],

Cell[BoxData[
    \(SNAP::"machineprecision" \(\(:\)\(\ \)\) 
      "SNAP function encounters a machine precision number. Machine precision \
numbers may not have enough accuracy due to Mathematica's inner operation \
policy."\)], "Message",
  CellLabel->"\\:6B21\\:3088\\:308A\\:FF1AIn[70]:="],

Cell[BoxData[
    RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(SNAP :: \\\"machineprecision\\\"\\) will be suppressed during this \
calculation. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::stop\\\"]\\)\"\>"}]], "Message",
  CellLabel->"\\:6B21\\:3088\\:308A\\:FF1AIn[70]:="],

Cell[BoxData[
    \(\((\(-1.`15.272219027674444\) + 
          x\^2 + \((\(\(2.`\)\(\[InvisibleSpace]\)\) + 
                1.`\ x)\)\ y)\)\ \((7.`15.377181505608839 + x\^3 - 
          1.0000000000000002`\ y + 
          0.9999999999999997`\ x\ y\^2)\)\)], "Output",
  CellLabel->"Out[70]="]
}, Open  ]],

Cell["\<\
If we use a SNAP structure, its tolerance is used as a backward \
error bound automatically.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(f2s = 
      SNAP[N@Expand[\((x^2 + y*x + 2  y - 1)\) \((x^3 + y^2\ x - y + 7)\)], 
        0.0000001`16]\)], "Input",
  CellLabel->"In[71]:="],

Cell[BoxData[
    \(\(-7.`\) + 7.`\ x\^2 - 1.`\ x\^3 + x\^5 + 15.`\ y + 7.`\ x\ y - 
      1.`\ x\^2\ y + 2.`\ x\^3\ y + x\^4\ y - 2.`\ y\^2 - 2.`\ x\ y\^2 + 
      x\^3\ y\^2 + 2.`\ x\ y\^3 + x\^2\ y\^3\)], "Output",
  CellLabel->"Out[71]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Chop@Factor[f2s]\)], "Input",
  CellLabel->"In[72]:="],

Cell[BoxData[
    \(\((\(-1.`15.317629257483443\) + 
          x\^2 + \((2.0000000000000000000069174357`14.093546064686803 + 
                1.0000000000000000000023999267`13.806630799766396\ x)\)\ y)\)\
\ \((7.`15.422591735417836 + x\^3 - 
          1.0000000000000000002183012924`13.05560191700747\ y + 
          0.9999999999999999998041428575`12.029207339667247\ x\ y\^2)\)\)], \
"Output",
  CellLabel->"Out[72]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Mathematical Background", "Section",
  ShowCellBracket->True],

Cell[CellGroupData[{

Cell["Approximate GCD and Divisors (univariate case)", "Subsection",
  ShowCellBracket->False],

Cell[TextData[{
  "Various approximate GCDs have been studied from the early period in \
history of symbolic numeric computations. The problem treated here is very \
simple, for the given polynomials ",
  Cell[BoxData[
      \(TraditionalForm\`g(x)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`h(x)\)]],
  " and the tolerance ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)]],
  ", finding polynomial ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\)]],
  " which maximizes its degree and satisfies"
}], "Text",
  ShowCellBracket->False],

Cell[BoxData[
    \(TextForm\`\(\(\[Exists] \(g\&_\) \((x)\) \[Element] \(P\_*\) \((g, \ \
\[Epsilon]\  \[DoubleVerticalBar] 
              g\( \[DoubleVerticalBar] \_*\))\)\)\(,\)\(\ \)\(\[Exists] \
\(h\&_\) \((x)\) \[Element] \(P\_*\) \((h, \ \[Epsilon]\  \
\[DoubleVerticalBar] 
              h\( \[DoubleVerticalBar] \_*\))\)\)\(,\)\(\ \)\(f \((x)\) | \(g\
\&_\) \((x)\)\)\(,\)\(\ \)\(f \((x)\) | \(h\&_\) \((x)\)\)\(,\)\(\ \)\)\)], \
"NumberedEquation",
  ShowCellBracket->False,
  CellMargins->{{103, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`*\)]],
  " denotes ",
  Cell[BoxData[
      \(TraditionalForm\`2\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Infinity]\)]],
  ", respectively. ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\)]],
  " is called ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)]],
  "-GCD of polynomials ",
  Cell[BoxData[
      \(TraditionalForm\`g(x)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`h(x)\)]],
  " with tolerance ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)]],
  ". Currently, we have implemented the algorithm by Pan [Pan01], for the ",
  Cell[BoxData[
      \(TraditionalForm\`2\)]],
  "-norm case only."
}], "Text",
  ShowCellBracket->False],

Cell["\<\
We note that there are also other approximate GCDs which have a \
little bit different definitions, and also approximate GCDs of multivariate \
polynomials. Those approximate GCDs will be implemented in the future \
release.\
\>", "Text",
  ShowCellBracket->False],

Cell[TextData[{
  "Considering approximate GCDs, the following concept of an ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)]],
  "-divisor is useful. For the given polynomial ",
  Cell[BoxData[
      \(TraditionalForm\`g(x)\)]],
  " and the tolerance ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)]],
  ", we call a polynomial ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\)]],
  " is an ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)]],
  "-divisor of ",
  Cell[BoxData[
      \(TraditionalForm\`g(x)\)]],
  " if ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\)]],
  " satisfies "
}], "Text",
  ShowCellBracket->False],

Cell[BoxData[
    \(TextForm\`\[Exists] \(g\&_\) \((x)\) \[Element] \(P\_*\) \((g, \ \
\[Epsilon]\  \[DoubleVerticalBar] g\( \[DoubleVerticalBar] \_*\))\), \ 
    f \((x)\) | \(g\&_\) \((x)\), \)], "NumberedEquation",
  ShowCellBracket->False,
  CellMargins->{{103, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`*\)]],
  " denotes ",
  Cell[BoxData[
      \(TraditionalForm\`2\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Infinity]\)]],
  ", respectively. Moreover, in this package, we call the quotient of ",
  Cell[BoxData[
      \(TraditionalForm\`\(g\&_\)(x)\)]],
  " by ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\)]],
  " an ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)]],
  "-quotient of ",
  Cell[BoxData[
      \(TraditionalForm\`g(x)\)]],
  " by ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\)]],
  ". These concepts are used in the Pan's algorithm and currently, we have \
implemented for the ",
  Cell[BoxData[
      \(TraditionalForm\`2\)]],
  "-norm case only."
}], "Text",
  ShowCellBracket->False],

Cell[TextData[{
  "Note that, theoretically, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)]],
  "-GCD, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)]],
  "-divisor and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)]],
  "-quotient are exact polynomials, since only the given polynomials have \
perturbation parts and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)]],
  "-GCD, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)]],
  "-divisor and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)]],
  "-quotient are treated as exact polynomials in that computations. However, \
due to numerical errors, in this package,  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)]],
  "-GCD, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)]],
  "-divisor and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)]],
  "-quotient are treated as SNAP structures."
}], "Text",
  ShowCellBracket->False]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Nearest Singular Polynomial (univariate case)", "Subsection",
  ShowCellBracket->False],

Cell[TextData[{
  "The nearest singular polynomial [KL96, ZW98, ZWNK01], of ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\)]],
  " is the nearest polynomial ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\&_\)(x)\)]],
  " which has a double root, minimizes ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[DoubleVerticalBar]\)\(f(x) - \(f\&_\)(
            x)\)\(\[DoubleVerticalBar]\)\)\)]],
  " and has the same degree as ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\)]],
  ". The similar problem that finds the nearest polynomial with constrained \
roots, has been studied [HK98, HKL99]."
}], "Text",
  ShowCellBracket->False],

Cell["\<\
In this package, finding the nearest singular polynomial can be \
written as follows.\
\>", "Text",
  ShowCellBracket->False],

Cell[TextData[{
  "For the given polynomial ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\)]],
  " and the tolerance ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)]],
  ", find a polynomial ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\&_\)(x)\)]],
  " satisfying "
}], "Text",
  ShowCellBracket->False],

Cell[BoxData[
    \(TextForm\`\(f\&_\) \((x)\) \[Element] \(P\_*\) \((f, \ \[Epsilon])\), \ \
\[Exists] c \[Element] \[DoubleStruckCapitalC], \ \((x - c)\)\^2 | \(f\&_\) \
\((x)\), \)], "NumberedEquation",
  ShowCellBracket->False,
  CellMargins->{{103, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`*\)]],
  " denotes ",
  Cell[BoxData[
      \(TraditionalForm\`1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`2\)]],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`\[Infinity]\)]],
  ", or output False which means that the nearest singular polynomial does \
not exist in the given SNAP structure. The current version of package solves \
this problem due to the known algorithm [ZWNK01], so the command can solve \
the problem for the ",
  Cell[BoxData[
      \(TraditionalForm\`2\)]],
  "-norm case only. The constrained roots version of the problem will be \
solvable in the future release."
}], "Text",
  ShowCellBracket->False],

Cell["\<\
Note that the current implementation outputs a normal polynomial \
(not in a SNAP structure) and the given tolerance for the command \
corresponding to the nearest singular polynomial does not have the same \
meaning of other commands of SNAP package. For more information, see \
[ZWNK01].\
\>", "Text",
  ShowCellBracket->False]
}, Open  ]],

Cell[CellGroupData[{

Cell["Irreducibility Testing for Bivariate Polynomials", "Subsection",
  ShowCellBracket->False],

Cell["\<\
Conventional ordinary factorization algorithms may always output \
\[OpenCurlyDoubleQuote]absolutely irreducible\[CloseCurlyDoubleQuote] for \
numerical or empirical polynomials since the given polynomial may have error \
parts on their coefficients even if the original polynomial is reducible. \
Moreover, if a numerical factorization algorithm, for example see [Sas01], \
outputs \[OpenCurlyDoubleQuote]no non-trivial factors found\
\[CloseCurlyDoubleQuote], it does not mean \[OpenCurlyDoubleQuote]absolutely \
irreducible\[CloseCurlyDoubleQuote] since those algorithms basically can find \
factors when the given polynomial is enough close to a reducible polynomial. \
Hence, the problem \[OpenCurlyDoubleQuote]irreducibility testing\
\[CloseCurlyDoubleQuote] is still important for numerical or empirical \
polynomials (for more informations, see [Kal95, KM03, Nag04c, Nag03, Nag02]).\
\
\>", "Text",
  ShowCellBracket->False],

Cell["In this package, the problem becomes as follows.", "Text",
  ShowCellBracket->False],

Cell[TextData[{
  "For the given SNAP structure ",
  Cell[BoxData[
      \(TraditionalForm\`\(P\_*\)(f, \[Epsilon])\)]],
  ", prove that any polynomial ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\&_\)(u\_1, \ \[Ellipsis], \ 
          u\_r) \[Element] \(P\_*\)(f, \[Epsilon])\)]],
  " is absolutely irreducible."
}], "Text",
  ShowCellBracket->False,
  CellMargins->{{87, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "The algorithm implemented in this package is due to Nagasaka [Nag04c] \
which is an improved version of the algorithm due to Kaltofen and May [KM03], \
for bivariate polynomials. Note that the current implementation is based on \
the algorithm for the ",
  Cell[BoxData[
      \(TraditionalForm\`2\)]],
  "-norm case, hence there are possibilities to be better for another norms. \
The version for more than two variables will be implemented in the future \
release. The largest problem to implement more than two variable cases is \
effectiveness and we have to wait further studies."
}], "Text",
  ShowCellBracket->False],

Cell[TextData[{
  "Those methods [KM03, Nag04c] use the coefficients of the given polynomial \
directly, so we can adapt it to the  ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s coefficient-wise accuracy concept. This is better than the originals, \
because treating tolerances as polynomial norms tends to be over-estimated. \
The current implementation can do this for polynomials not in SNAP \
structures."
}], "Text",
  ShowCellBracket->False]
}, Open  ]],

Cell[CellGroupData[{

Cell["Numerical Factorization of Multivariate Polynomials", "Subsection",
  ShowCellBracket->False],

Cell["\<\
The same reason of the above irreducibility testing, we have to use \
completely different factorization algorithms for numerical or empirical \
polynomials. In this package, we have implemented the Sasaki's algorithm \
[Sas01] with a degree bound studied by Bostan et al. [BLSSW04]. Currently, \
for non-monic polynomials, the command is not stable since non of approximate \
GCD algorithms for multivariate polynomials which are needed for factoring \
non-monic polynomials, is implemented.\
\>", "Text",
  ShowCellBracket->False],

Cell["\<\
Note that the given polynomial may have approximate factors (or \
called numerical or pseudo factors) even if the algorithm outputs \
\[OpenCurlyDoubleQuote]absolutely irreducible\[CloseCurlyDoubleQuote]  or \
\[OpenCurlyDoubleQuote]no factors\[CloseCurlyDoubleQuote]. Therefore, you are \
encouraged to use the above irreducibility testing when you do not get \
approximate factors.\
\>", "Text",
  ShowCellBracket->False]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["References", "Chapter",
  ShowCellBracket->True],

Cell["\<\
[BL98] B. Beckermann and G. Labahn. When are two numerical \
polynomials relatively prime? J. Symb. Comput., 267:677-689, 1998.\
\>", \
"Reference"],

Cell["\<\
[BLSSW04] A. Bostan, G. Lecerf, B. Salvy, E. Schost, and B. \
Wiebelt. Complexity Issues in Bivariate Polynomial Factorization. In \
Proceedings of the 2004 International Symposium on Symbolic and Algebraic \
Computation, ISSAC 2004, pages 42-49, 2004.\
\>", "Reference"],

Cell["\<\
[CGTW95] R. M. Corless, P. M. Gianni, B. M. Trager, and S. M. Watt. \
The singular value decomposition for polynomial systems. In Proceedings of \
the 1995 International Symposium on Symbolic and Algebraic Computation, ISSAC \
'95, pages 195-207, 1995.\
\>", "Reference"],

Cell["\<\
[CGHKW01] R. M. Corless, M. W. Giesbrecht, M. Hoeij, I. S. \
Kotsireas, and S. M. Watt. Towards factoring bivariate approximate \
polynomials. In Proceedings of the 2001 International Symposium on Symbolic \
and Algebraic Computation, ISSAC 2001, pages 85-92, 2001.\
\>", "Reference"],

Cell["\<\
[EGL97] I. Z. Emiris, A. Galligo, and H. Lombardi. Certified \
approximate univariate gcds. J. Pure Appl. Algebra, 117&118:229-251, \
1997.\
\>", "Reference"],

Cell["\<\
[GR03] S. Gao and V. M. Rodrigues. Irreducibility of polynomials \
modulo p via Newton Polytopes. J. Number Theory, 101:32-47, 2003.\
\>", \
"Reference"],

Cell["\<\
[GL96] G. H. Golub and C. F. V. Loan. Matrix Computations Third \
Edition, Johns Hopkins Series in the Mathematical Sciences. The Johns Hopkins \
University Press, Baltimore, 1996.\
\>", "Reference"],

Cell["\<\
[HK98] M. A. Hitz and E. Kaltofen. Efficient algorithms for \
computing the nearest polynomial with constrained roots. In Proceedings of \
the 1998 International Symposium on Symbolic and Algebraic Computation, ISSAC \
'98, pages 236-243, 1998.\
\>", "Reference"],

Cell["\<\
[HKL99] M. A. Hitz, E. Kaltofen, and Y. N. Lakshman. Efficient \
algorithms for computing the nearest polynomial with a real root and related \
problems. In Proceedings of the 1999 International Symposium on Symbolic and \
Algebraic Computation, ISSAC '99, pages 205-212, 1999.\
\>", "Reference"],

Cell["\<\
[KS97] F. Kako and T. Sasaki. Proposal of \"effective \
floating-point number\" for approximate algebraic computation. preprint, \
1997.\
\>", "Reference"],

Cell["\<\
[Kal95] E. Kaltofen. Effective Noether irreducibility forms and \
applications. J. Computer and System Sciences, 50:274-295, 1995.\
\>", \
"Reference"],

Cell["\<\
[KM03] E. Kaltofen and J. May. On Approximate Irreducibility of \
Polynomials in Several Variables. In Proceedings of the 2003 International \
Symposium on Symbolic and Algebraic Computation, ISSAC 2003, pages 161-168, \
2003.\
\>", "Reference"],

Cell["\<\
[KL96] N. Karmarkar and Y. N. Lakshman. Approximate polynomial \
greatest common divisors and nearest singular polynomials. In Proceedings of \
the 1996 International Symposium on Symbolic and Algebraic Computation, ISSAC \
'96, pages 35-39, 1996.\
\>", "Reference"],

Cell["\<\
[MU88] Z. Mou-tan and R. Unbehauen. Approximate factorization of \
multivariate polynomials. Signal Processing, 14:141-152, 1988.\
\>", \
"Reference"],

Cell["\<\
[Nag04a] K. Nagasaka. SNAP Package(Talk in Japanese). JSSAC 2004. \
2004.\
\>", "Reference"],

Cell["\<\
[Nag04b] K. Nagasaka. SNAP Package and Its Applications. ATCM 2004. \
2004.\
\>", "Reference"],

Cell["\<\
[Nag04c] K. Nagasaka.  Towards More Accurate Separation Bounds of \
Empirical Polynomials. SIGSAM Bulletin, Formally Reviewed Articles, \
38(4):119-129, 2004.\
\>", "Reference"],

Cell["\<\
[Nag03] K. Nagasaka. Neighborhood Irreducibility Testing of \
Multivariate Polynomials. In Proc. Computer Algebra in Scientific Computing, \
CASC2003, pages 283-292, 2003.\
\>", "Reference"],

Cell["\<\
[Nag02] K. Nagasaka. Towards Certified Irreducibility Testing of \
Bivariate Approximate Polynomials. In Proc. International Symposium on \
Symbolic and Algebraic Computation, ISSAC2002, pages 192-199, 2002.\
\>", \
"Reference"],

Cell["\<\
[Pan98] V. Y. Pan. Approximate polynomial gcds, pad'e \
approximation, polynomial zeros and bipartite graphs. In Proc. Ninth Annual \
ACM-SIAM Symp. on Discrete Algorithms, pages 68-77, 1998.\
\>", "Reference"],

Cell["\<\
[Pan01] V. Y. Pan. Computation of approximate polynomial gcds and \
an extension. Inform. and Comput., 167(2):71-85, 2001.\
\>", "Reference"],

Cell[TextData[{
  "[Rup99] W. M. Ruppert. Reducibility of polynomials ",
  Cell[BoxData[
      \(TraditionalForm\`f(x, y)\)]],
  " modulo ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  ". J. Number Theory, 77:62-70, 1999."
}], "Reference"],

Cell["\<\
[Sas01] T. Sasaki. Approximate multivariate polynomial \
factorization based on zero-sum relations. In Proceedings of the 2001 \
International Symposium on Symbolic and Algebraic Computation, ISSAC 2001, \
pages 284-291.\
\>", "Reference"],

Cell["\<\
[Smi70] B. Smith. Error bounds for zeros of a polynomial based upon \
Gerschgorin's theorems. J. Assoc. Comput. Mach., 17:661-674, 1970.\
\>", \
"Reference"],

Cell["\<\
[TS00] A. Terui and T. Sasaki. \"approximate zero-points\" of real \
univariate polynomial with large error terms. IPSJ J., 41:974-989, \
2000.\
\>", "Reference"],

Cell["\<\
[WSZ00] Y. H. W. Wu, H. J. Stetter, and L. Zhi. Pseudofactors of \
multivariate polynomials. In Proceedings of the 2000 International Symposium \
on Symbolic and Algebraic Computation, ISSAC 2000, pages 161-168, 2000.\
\>", \
"Reference"],

Cell["\<\
[Zen04] Z. Zeng. The approximate GCD of inexact polynomials. Part \
I: a univariate algorithm. Preprint, 2004.\
\>", "Reference"],

Cell["\<\
[ZW98] L. Zhi and W. Wu. Nearest singular polynomials. J. Symbolic \
Comput., 26(6):667-675, 1998.\
\>", "Reference"],

Cell["\<\
[ZWNK01] L. Zhi, W. Wu, M.-T. Noda, and H. Kai. Hybrid method for \
computing the nearest singular polynomials. MM Research Preprints, \
20:229-239, 2001.\
\>", "Reference"],

Cell[CellGroupData[{

Cell["About the Author", "Section"],

Cell[TextData[{
  "Kosaku Nagasaka is an assistant Professor at Kobe University, JAPAN. He \
worked for Wolfram Research on the summer 1999 student internship program. \
His main research topic is symbolic numeric algorithms for polynomials. From  \
2001, he has worked for Japanese ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " User Group as one of directors."
}], "Text"],

Cell[TextData[{
  StyleBox["Kosaku Nagasaka",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  ", Division of Mathematics and Informatics, Department of Science of Human \
Environment, Faculty of Human Development, Kobe University, Japan\n",
  ButtonBox["nagasaka@main.h.kobe-u.ac.jp",
    ButtonData:>{
      URL[ "mailto:nagasaka@main.h.kobe-u.ac.jp"], None},
    ButtonStyle->"Hyperlink"]
}], "Text",
  CellMargins->{{Inherited, Inherited}, {Inherited, 30}},
  CellGroupingRules->{"SectionGrouping", 40},
  FontSlant->"Italic"]
}, Open  ]]
}, Closed]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 693}},
ScreenStyleEnvironment->"Working",
WindowToolbars->"EditBar",
WindowSize->{730, 666},
WindowMargins->{{Automatic, 115}, {Automatic, -2}},
Visible->True,
Magnification->1,
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 110, 3, 25, "Text"],

Cell[CellGroupData[{
Cell[1889, 58, 24, 0, 65, "Section"],
Cell[1916, 60, 143, 4, 25, "Text"],
Cell[2062, 66, 323, 7, 42, "Abstract"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2422, 78, 31, 0, 92, "Chapter"],
Cell[2456, 80, 889, 19, 110, "Text"],
Cell[3348, 101, 781, 16, 93, "Text"],
Cell[4132, 119, 1165, 26, 127, "Text"],
Cell[5300, 147, 195, 4, 42, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5532, 156, 59, 0, 92, "Chapter"],
Cell[5594, 158, 297, 9, 42, "Text"],
Cell[5894, 169, 2365, 63, 244, "DefinitionBox"],
Cell[8262, 234, 216, 7, 30, "SmallTextSans"],

Cell[CellGroupData[{
Cell[8503, 245, 37, 0, 65, "Section"],
Cell[8543, 247, 128, 3, 25, "Text"],
Cell[8674, 252, 75, 2, 29, "Input"],
Cell[8752, 256, 136317, 1963, 114, "DefinitionBox"],
Cell[145072, 2221, 206, 3, 42, "Print"],
Cell[145281, 2226, 412, 8, 59, "Text"],

Cell[CellGroupData[{
Cell[145718, 2238, 170, 4, 29, "Input"],
Cell[145891, 2244, 166, 3, 27, "Output"]
}, Open  ]],
Cell[146072, 2250, 140, 5, 25, "Text"],

Cell[CellGroupData[{
Cell[146237, 2259, 68, 2, 29, "Input"],
Cell[146308, 2263, 587, 13, 117, "Output"]
}, Open  ]],
Cell[146910, 2279, 166, 6, 25, "Text"],

Cell[CellGroupData[{
Cell[147101, 2289, 69, 2, 29, "Input"],
Cell[147173, 2293, 119, 3, 27, "Output"]
}, Open  ]],
Cell[147307, 2299, 69, 0, 25, "Text"],

Cell[CellGroupData[{
Cell[147401, 2303, 65, 2, 29, "Input"],
Cell[147469, 2307, 170, 3, 28, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[147676, 2315, 70, 2, 29, "Input"],
Cell[147749, 2319, 108, 2, 27, "Output"]
}, Open  ]],
Cell[147872, 2324, 330, 9, 42, "Text"],

Cell[CellGroupData[{
Cell[148227, 2337, 92, 2, 29, "Input"],
Cell[148322, 2341, 62, 2, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[148421, 2348, 92, 2, 29, "Input"],
Cell[148516, 2352, 63, 2, 27, "Output"]
}, Open  ]],
Cell[148594, 2357, 168, 5, 25, "Text"],

Cell[CellGroupData[{
Cell[148787, 2366, 78, 2, 29, "Input"],
Cell[148868, 2370, 438, 10, 79, "Output"]
}, Open  ]],
Cell[149321, 2383, 108, 3, 25, "Text"],

Cell[CellGroupData[{
Cell[149454, 2390, 68, 2, 29, "Input"],
Cell[149525, 2394, 300, 5, 46, "Output"]
}, Open  ]],
Cell[149840, 2402, 107, 3, 25, "Text"],

Cell[CellGroupData[{
Cell[149972, 2409, 75, 2, 29, "Input"],
Cell[150050, 2413, 110, 2, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[150197, 2420, 71, 2, 29, "Input"],
Cell[150271, 2424, 111, 2, 27, "Output"]
}, Open  ]],
Cell[150397, 2429, 163, 4, 25, "Text"],

Cell[CellGroupData[{
Cell[150585, 2437, 59, 2, 29, "Input"],
Cell[150647, 2441, 167, 3, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[150851, 2449, 65, 2, 29, "Input"],
Cell[150919, 2453, 248, 4, 35, "Message"],
Cell[151170, 2459, 160, 3, 27, "Output"]
}, Open  ]],
Cell[151345, 2465, 128, 3, 25, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[151510, 2473, 67, 1, 65, "Section"],

Cell[CellGroupData[{
Cell[151602, 2478, 42, 0, 40, "Subsection"],
Cell[151647, 2480, 610, 11, 88, "Text"],
Cell[152260, 2493, 68, 1, 24, "Text"],
Cell[152331, 2496, 502, 13, 40, "Text"],
Cell[152836, 2511, 508, 8, 34, "NumberedEquation"],
Cell[153347, 2521, 508, 8, 34, "NumberedEquation"],
Cell[153858, 2531, 538, 8, 34, "NumberedEquation"],
Cell[154399, 2541, 265, 7, 25, "Text"],
Cell[154667, 2550, 345, 5, 42, "NumberedEquation"],
Cell[155015, 2557, 397, 14, 24, "Text"],
Cell[155415, 2573, 46, 1, 24, "Text"],
Cell[155464, 2576, 164, 4, 24, "Text"],
Cell[155631, 2582, 519, 8, 34, "NumberedEquation"],
Cell[156153, 2592, 352, 9, 40, "Text"],
Cell[156508, 2603, 332, 5, 31, "NumberedEquation"],
Cell[156843, 2610, 510, 14, 56, "Text"],
Cell[157356, 2626, 232, 5, 40, "Text"],
Cell[157591, 2633, 49, 1, 24, "Text"],
Cell[157643, 2636, 107, 1, 24, "Text"],
Cell[157753, 2639, 259, 4, 38, "NumberedEquation"],
Cell[158015, 2645, 214, 3, 30, "NumberedEquation"],
Cell[158232, 2650, 204, 3, 30, "NumberedEquation"],
Cell[158439, 2655, 214, 3, 30, "NumberedEquation"],
Cell[158656, 2660, 269, 4, 38, "NumberedEquation"],
Cell[158928, 2666, 278, 4, 31, "NumberedEquation"],
Cell[159209, 2672, 385, 14, 26, "Text"],
Cell[159597, 2688, 45, 1, 24, "Text"],
Cell[159645, 2691, 312, 9, 24, "Text"],
Cell[159960, 2702, 702, 12, 55, "NumberedEquation"],
Cell[160665, 2716, 535, 9, 48, "NumberedEquation"],
Cell[161203, 2727, 708, 12, 49, "NumberedEquation"],
Cell[161914, 2741, 549, 20, 26, "Text"],
Cell[162466, 2763, 54, 1, 24, "Text"],
Cell[162523, 2766, 253, 5, 40, "Text"],
Cell[162779, 2773, 262, 4, 30, "NumberedEquation"],
Cell[163044, 2779, 289, 5, 33, "NumberedEquation"],
Cell[163336, 2786, 299, 5, 34, "NumberedEquation"],
Cell[163638, 2793, 428, 16, 25, "Text"],
Cell[164069, 2811, 45, 1, 24, "Text"],
Cell[164117, 2814, 311, 9, 24, "Text"],
Cell[164431, 2825, 401, 7, 34, "NumberedEquation"],
Cell[164835, 2834, 107, 1, 24, "Text"],
Cell[164945, 2837, 791, 13, 66, "NumberedEquation"],
Cell[165739, 2852, 791, 13, 66, "NumberedEquation"],
Cell[166533, 2867, 831, 13, 66, "NumberedEquation"],
Cell[167367, 2882, 549, 20, 26, "Text"],
Cell[167919, 2904, 54, 1, 24, "Text"],
Cell[167976, 2907, 148, 4, 24, "Text"],
Cell[168127, 2913, 552, 12, 57, "Text"],
Cell[168682, 2927, 261, 4, 30, "NumberedEquation"],
Cell[168946, 2933, 415, 12, 40, "Text"],
Cell[169364, 2947, 555, 9, 32, "NumberedEquation"],
Cell[169922, 2958, 326, 14, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[170285, 2977, 47, 0, 40, "Subsection"],
Cell[170335, 2979, 220, 4, 40, "Text"],
Cell[170558, 2985, 706, 20, 56, "Text"],
Cell[171267, 3007, 118, 2, 40, "DefinitionBox"],
Cell[171388, 3011, 284, 5, 56, "Text"],
Cell[171675, 3018, 241, 5, 42, "Input",
  Evaluatable->False],
Cell[171919, 3025, 124, 3, 26, "Input",
  Evaluatable->False],
Cell[172046, 3030, 168, 3, 42, "Input",
  Evaluatable->False],
Cell[172217, 3035, 212, 5, 42, "Input",
  Evaluatable->False],
Cell[172432, 3042, 151, 3, 26, "Input",
  Evaluatable->False],
Cell[172586, 3047, 105, 2, 26, "Input",
  Evaluatable->False],
Cell[172694, 3051, 384, 10, 44, "Text"],
Cell[173081, 3063, 103, 2, 26, "Input",
  Evaluatable->False]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[173245, 3072, 41, 0, 92, "Chapter"],
Cell[173289, 3074, 204, 4, 42, "Text"],
Cell[173496, 3080, 4238, 112, 156, "DefinitionBox"],
Cell[177737, 3194, 222, 7, 30, "SmallTextSans"],

Cell[CellGroupData[{
Cell[177984, 3205, 27, 0, 65, "Section"],
Cell[178014, 3207, 134, 3, 25, "Text"],

Cell[CellGroupData[{
Cell[178173, 3214, 59, 2, 29, "Input"],
Cell[178235, 3218, 167, 3, 27, "Output"]
}, Open  ]],
Cell[178417, 3224, 360, 6, 59, "Text"],
Cell[178780, 3232, 79, 0, 33, "Commentary"],

Cell[CellGroupData[{
Cell[178884, 3236, 75, 2, 29, "Input"],
Cell[178962, 3240, 515, 9, 46, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[179514, 3254, 83, 2, 29, "Input"],
Cell[179600, 3258, 363, 6, 46, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[180000, 3269, 83, 2, 29, "Input"],
Cell[180086, 3273, 519, 9, 46, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[180642, 3287, 83, 2, 29, "Input"],
Cell[180728, 3291, 364, 6, 46, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[181129, 3302, 211, 5, 30, "Input"],
Cell[181343, 3309, 517, 9, 46, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[181897, 3323, 83, 2, 29, "Input"],
Cell[181983, 3327, 363, 6, 46, "Output"]
}, Open  ]],
Cell[182361, 3336, 71, 0, 33, "Commentary"],

Cell[CellGroupData[{
Cell[182457, 3340, 96, 2, 29, "Input"],
Cell[182556, 3344, 332, 5, 46, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[182925, 3354, 83, 2, 29, "Input"],
Cell[183011, 3358, 385, 7, 46, "Output"]
}, Open  ]],
Cell[183411, 3368, 94, 3, 25, "Text"],

Cell[CellGroupData[{
Cell[183530, 3375, 74, 2, 29, "Input"],
Cell[183607, 3379, 300, 5, 46, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[183944, 3389, 101, 2, 29, "Input"],
Cell[184048, 3393, 110, 2, 27, "Output"]
}, Open  ]],
Cell[184173, 3398, 366, 12, 42, "Text"],

Cell[CellGroupData[{
Cell[184564, 3414, 128, 3, 29, "Input"],
Cell[184695, 3419, 378, 6, 46, "Output"]
}, Open  ]],
Cell[185088, 3428, 103, 3, 25, "Text"],

Cell[CellGroupData[{
Cell[185216, 3435, 88, 2, 29, "Input"],
Cell[185307, 3439, 378, 6, 46, "Output"]
}, Open  ]],
Cell[185700, 3448, 437, 13, 42, "Text"],

Cell[CellGroupData[{
Cell[186162, 3465, 139, 3, 29, "Input"],
Cell[186304, 3470, 246, 4, 35, "Message"],
Cell[186553, 3476, 246, 4, 35, "Message"],
Cell[186802, 3482, 246, 4, 35, "Message"],
Cell[187051, 3488, 384, 6, 20, "Message"],
Cell[187438, 3496, 195, 4, 27, "Output"]
}, Open  ]],
Cell[187648, 3503, 168, 5, 25, "Text"],

Cell[CellGroupData[{
Cell[187841, 3512, 80, 2, 29, "Input"],
Cell[187924, 3516, 72, 2, 27, "Output"]
}, Open  ]],
Cell[188011, 3521, 154, 4, 25, "Text"],

Cell[CellGroupData[{
Cell[188190, 3529, 82, 2, 29, "Input"],
Cell[188275, 3533, 500, 9, 46, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[188812, 3547, 83, 2, 29, "Input"],
Cell[188898, 3551, 357, 6, 46, "Output"]
}, Open  ]],
Cell[189270, 3560, 335, 6, 59, "Text"],

Cell[CellGroupData[{
Cell[189630, 3570, 82, 2, 29, "Input"],
Cell[189715, 3574, 237, 4, 35, "Message"],
Cell[189955, 3580, 940, 16, 46, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[190932, 3601, 83, 2, 29, "Input"],
Cell[191018, 3605, 660, 11, 65, "Output"]
}, Open  ]],
Cell[191693, 3619, 87, 3, 25, "Text"],

Cell[CellGroupData[{
Cell[191805, 3626, 72, 2, 29, "Input"],
Cell[191880, 3630, 282, 5, 46, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[192199, 3640, 77, 2, 29, "Input"],
Cell[192279, 3644, 679, 12, 46, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[192995, 3661, 83, 2, 29, "Input"],
Cell[193081, 3665, 603, 10, 65, "Output"]
}, Open  ]],
Cell[193699, 3678, 202, 5, 25, "Text"],

Cell[CellGroupData[{
Cell[193926, 3687, 81, 2, 29, "Input"],
Cell[194010, 3691, 758, 13, 65, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[194805, 3709, 83, 2, 29, "Input"],
Cell[194891, 3713, 629, 10, 65, "Output"]
}, Open  ]],
Cell[195535, 3726, 390, 10, 42, "Text"],

Cell[CellGroupData[{
Cell[195950, 3740, 158, 4, 29, "Input"],
Cell[196111, 3746, 155, 3, 43, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[196303, 3754, 80, 2, 29, "Input"],
Cell[196386, 3758, 501, 9, 63, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[196924, 3772, 110, 2, 29, "Input"],
Cell[197037, 3776, 371, 7, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[197445, 3788, 102, 2, 29, "Input"],
Cell[197550, 3792, 419, 8, 46, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[198018, 3806, 67, 1, 65, "Section"],

Cell[CellGroupData[{
Cell[198110, 3811, 59, 0, 40, "Subsection"],
Cell[198172, 3813, 559, 23, 25, "Text"],
Cell[198734, 3838, 463, 8, 46, "NumberedEquation"],
Cell[199200, 3848, 320, 14, 24, "Text"],
Cell[199523, 3864, 207, 3, 30, "NumberedEquation"],
Cell[199733, 3869, 385, 14, 25, "Text"],
Cell[200121, 3885, 348, 6, 33, "NumberedEquation"],
Cell[200472, 3893, 194, 4, 24, "Text"],
Cell[200669, 3899, 75, 1, 24, "Text"],
Cell[200747, 3902, 108, 1, 24, "Text"],
Cell[200858, 3905, 261, 4, 34, "NumberedEquation"],
Cell[201122, 3911, 81, 1, 24, "Text"],
Cell[201206, 3914, 1000, 16, 90, "NumberedEquation"],
Cell[202209, 3932, 75, 1, 24, "Text"],
Cell[202287, 3935, 108, 1, 24, "Text"],
Cell[202398, 3938, 242, 4, 32, "NumberedEquation"],
Cell[202643, 3944, 81, 1, 24, "Text"],
Cell[202727, 3947, 858, 14, 68, "NumberedEquation"],
Cell[203588, 3963, 75, 1, 24, "Text"],
Cell[203666, 3966, 108, 1, 24, "Text"],
Cell[203777, 3969, 287, 4, 32, "NumberedEquation"],
Cell[204067, 3975, 81, 1, 24, "Text"],
Cell[204151, 3978, 1065, 16, 79, "NumberedEquation"],
Cell[205219, 3996, 328, 11, 24, "Text"],
Cell[205550, 4009, 1152, 21, 119, "NumberedEquation"]
}, Open  ]],

Cell[CellGroupData[{
Cell[206739, 4035, 72, 0, 40, "Subsection"],
Cell[206814, 4037, 430, 7, 72, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[207281, 4049, 62, 0, 40, "Subsection"],
Cell[207346, 4051, 391, 8, 56, "Text"],
Cell[207740, 4061, 353, 6, 56, "Text"],
Cell[208096, 4069, 67, 1, 24, "Text"],
Cell[208166, 4072, 217, 6, 25, "Text"],
Cell[208386, 4080, 672, 16, 65, "NumberedEquation"],
Cell[209061, 4098, 946, 32, 43, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[210044, 4135, 68, 0, 40, "Subsection"],
Cell[210115, 4137, 188, 4, 40, "Text"],
Cell[210306, 4143, 45, 1, 24, "Text"],
Cell[210354, 4146, 254, 7, 25, "Text"],
Cell[210611, 4155, 412, 6, 51, "NumberedEquation"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[211084, 4168, 58, 0, 92, "Chapter"],
Cell[211145, 4170, 324, 6, 59, "Text"],
Cell[211472, 4178, 3978, 96, 244, "DefinitionBox"],
Cell[215453, 4276, 227, 7, 30, "SmallTextSans"],

Cell[CellGroupData[{
Cell[215705, 4287, 27, 0, 65, "Section"],
Cell[215735, 4289, 133, 3, 25, "Text"],

Cell[CellGroupData[{
Cell[215893, 4296, 59, 2, 29, "Input"],
Cell[215955, 4300, 167, 3, 27, "Output"]
}, Open  ]],
Cell[216137, 4306, 143, 3, 25, "Text"],

Cell[CellGroupData[{
Cell[216305, 4313, 155, 4, 29, "Input"],
Cell[216463, 4319, 197, 4, 27, "Output"]
}, Open  ]],
Cell[216675, 4326, 75, 0, 25, "Text"],

Cell[CellGroupData[{
Cell[216775, 4330, 92, 2, 29, "Input"],
Cell[216870, 4334, 66, 2, 40, "Output"]
}, Open  ]],
Cell[216951, 4339, 222, 8, 25, "Text"],

Cell[CellGroupData[{
Cell[217198, 4351, 98, 2, 29, "Input"],
Cell[217299, 4355, 176, 3, 20, "Message"],
Cell[217478, 4360, 203, 4, 27, "Output"]
}, Open  ]],
Cell[217696, 4367, 58, 0, 25, "Text"],

Cell[CellGroupData[{
Cell[217779, 4371, 100, 2, 29, "Input"],
Cell[217882, 4375, 63, 2, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[217982, 4382, 100, 2, 29, "Input"],
Cell[218085, 4386, 164, 3, 27, "Output"]
}, Open  ]],
Cell[218264, 4392, 109, 3, 25, "Text"],

Cell[CellGroupData[{
Cell[218398, 4399, 87, 2, 29, "Input"],
Cell[218488, 4403, 176, 3, 20, "Message"],
Cell[218667, 4408, 90, 2, 27, "Output"]
}, Open  ]],
Cell[218772, 4413, 98, 3, 25, "Text"],

Cell[CellGroupData[{
Cell[218895, 4420, 82, 2, 29, "Input"],
Cell[218980, 4424, 95, 2, 27, "Output"]
}, Open  ]],
Cell[219090, 4429, 234, 8, 25, "Text"],

Cell[CellGroupData[{
Cell[219349, 4441, 92, 2, 29, "Input"],
Cell[219444, 4445, 176, 3, 20, "Message"],
Cell[219623, 4450, 623, 11, 103, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[220283, 4466, 82, 2, 29, "Input"],
Cell[220368, 4470, 237, 4, 35, "Message"],
Cell[220608, 4476, 537, 11, 84, "Output"]
}, Open  ]],
Cell[221160, 4490, 129, 3, 25, "Text"],

Cell[CellGroupData[{
Cell[221314, 4497, 153, 4, 29, "Input"],
Cell[221470, 4503, 230, 4, 46, "Output"]
}, Open  ]],
Cell[221715, 4510, 161, 5, 25, "Text"],

Cell[CellGroupData[{
Cell[221901, 4519, 95, 2, 29, "Input"],
Cell[221999, 4523, 63, 2, 27, "Output"]
}, Open  ]],
Cell[222077, 4528, 145, 3, 25, "Text"],

Cell[CellGroupData[{
Cell[222247, 4535, 82, 2, 29, "Input"],
Cell[222332, 4539, 252, 4, 46, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[222621, 4548, 84, 2, 29, "Input"],
Cell[222708, 4552, 63, 2, 27, "Output"]
}, Open  ]],
Cell[222786, 4557, 274, 8, 25, "Text"],

Cell[CellGroupData[{
Cell[223085, 4569, 76, 2, 29, "Input"],
Cell[223164, 4573, 108, 2, 27, "Output"]
}, Open  ]],
Cell[223287, 4578, 291, 6, 42, "Text"],

Cell[CellGroupData[{
Cell[223603, 4588, 83, 2, 29, "Input"],
Cell[223689, 4592, 63, 2, 27, "Output"]
}, Open  ]],
Cell[223767, 4597, 91, 3, 25, "Text"],

Cell[CellGroupData[{
Cell[223883, 4604, 150, 4, 29, "Input"],
Cell[224036, 4610, 242, 4, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[224315, 4619, 75, 2, 29, "Input"],
Cell[224393, 4623, 292, 5, 46, "Output"]
}, Open  ]],
Cell[224700, 4631, 122, 3, 25, "Text"],

Cell[CellGroupData[{
Cell[224847, 4638, 87, 2, 29, "Input"],
Cell[224937, 4642, 294, 5, 50, "Message"],
Cell[225234, 4649, 294, 5, 50, "Message"],
Cell[225531, 4656, 294, 5, 50, "Message"],
Cell[225828, 4663, 393, 6, 35, "Message"],
Cell[226224, 4671, 293, 6, 27, "Output"]
}, Open  ]],
Cell[226532, 4680, 116, 3, 25, "Text"],

Cell[CellGroupData[{
Cell[226673, 4687, 163, 4, 29, "Input"],
Cell[226839, 4693, 242, 4, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[227118, 4702, 74, 2, 29, "Input"],
Cell[227195, 4706, 419, 8, 46, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[227663, 4720, 67, 1, 65, "Section"],

Cell[CellGroupData[{
Cell[227755, 4725, 94, 1, 40, "Subsection"],
Cell[227852, 4728, 559, 17, 56, "Text"],
Cell[228414, 4747, 543, 10, 33, "NumberedEquation"],
Cell[228960, 4759, 812, 33, 40, "Text"],
Cell[229775, 4794, 274, 6, 40, "Text"],
Cell[230052, 4802, 654, 24, 40, "Text"],
Cell[230709, 4828, 302, 5, 30, "NumberedEquation"],
Cell[231014, 4835, 860, 34, 40, "Text"],
Cell[231877, 4871, 964, 32, 56, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[232878, 4908, 97, 1, 40, "Subsection"],
Cell[232978, 4911, 637, 17, 58, "Text"],
Cell[233618, 4930, 135, 4, 24, "Text"],
Cell[233756, 4936, 318, 12, 25, "Text"],
Cell[234077, 4950, 290, 5, 33, "NumberedEquation"],
Cell[234370, 4957, 712, 22, 56, "Text"],
Cell[235085, 4981, 339, 7, 56, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[235461, 4993, 96, 1, 40, "Subsection"],
Cell[235560, 4996, 942, 15, 104, "Text"],
Cell[236505, 5013, 90, 1, 24, "Text"],
Cell[236598, 5016, 412, 11, 25, "Text"],
Cell[237013, 5029, 642, 12, 88, "Text"],
Cell[237658, 5043, 462, 10, 56, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[238157, 5058, 99, 1, 40, "Subsection"],
Cell[238259, 5061, 542, 9, 72, "Text"],
Cell[238804, 5072, 433, 8, 56, "Text"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[239298, 5087, 54, 1, 92, "Chapter"],
Cell[239355, 5090, 158, 4, 25, "Reference"],
Cell[239516, 5096, 281, 5, 42, "Reference"],
Cell[239800, 5103, 281, 5, 42, "Reference"],
Cell[240084, 5110, 294, 5, 59, "Reference"],
Cell[240381, 5117, 168, 4, 42, "Reference"],
Cell[240552, 5123, 163, 4, 42, "Reference"],
Cell[240718, 5129, 209, 4, 42, "Reference"],
Cell[240930, 5135, 273, 5, 42, "Reference"],
Cell[241206, 5142, 306, 5, 59, "Reference"],
Cell[241515, 5149, 165, 4, 25, "Reference"],
Cell[241683, 5155, 161, 4, 25, "Reference"],
Cell[241847, 5161, 255, 5, 42, "Reference"],
Cell[242105, 5168, 276, 5, 42, "Reference"],
Cell[242384, 5175, 160, 4, 25, "Reference"],
Cell[242547, 5181, 102, 3, 25, "Reference"],
Cell[242652, 5186, 104, 3, 25, "Reference"],
Cell[242759, 5191, 187, 4, 42, "Reference"],
Cell[242949, 5197, 200, 4, 42, "Reference"],
Cell[243152, 5203, 238, 5, 42, "Reference"],
Cell[243393, 5210, 220, 4, 42, "Reference"],
Cell[243616, 5216, 151, 3, 25, "Reference"],
Cell[243770, 5221, 245, 8, 25, "Reference"],
Cell[244018, 5231, 249, 5, 42, "Reference"],
Cell[244270, 5238, 167, 4, 42, "Reference"],
Cell[244440, 5244, 172, 4, 42, "Reference"],
Cell[244615, 5250, 248, 5, 42, "Reference"],
Cell[244866, 5257, 139, 3, 25, "Reference"],
Cell[245008, 5262, 127, 3, 25, "Reference"],
Cell[245138, 5267, 183, 4, 42, "Reference"],

Cell[CellGroupData[{
Cell[245346, 5275, 35, 0, 65, "Section"],
Cell[245384, 5277, 386, 8, 59, "Text"],
Cell[245773, 5287, 532, 13, 89, "Text",
  CellGroupingRules->{"SectionGrouping", 40}]
}, Open  ]]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

